# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: APIRequest.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import enterprise_pb2 as enterprise__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x41PIRequest.proto\x12\x0e\x41uthentication\x1a\x10\x65nterprise.proto\"\xb0\x01\n\nApiRequest\x12 \n\x18\x65ncryptedTransmissionKey\x18\x01 \x01(\x0c\x12\x13\n\x0bpublicKeyId\x18\x02 \x01(\x05\x12\x0e\n\x06locale\x18\x03 \x01(\t\x12\x18\n\x10\x65ncryptedPayload\x18\x04 \x01(\x0c\x12\x16\n\x0e\x65ncryptionType\x18\x05 \x01(\x05\x12\x11\n\trecaptcha\x18\x06 \x01(\t\x12\x16\n\x0esubEnvironment\x18\x07 \x01(\t\"j\n\x11\x41piRequestPayload\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\x12\x1d\n\x15\x65ncryptedSessionToken\x18\x02 \x01(\x0c\x12\x11\n\ttimeToken\x18\x03 \x01(\x0c\x12\x12\n\napiVersion\x18\x04 \x01(\x05\"6\n\tTransform\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x02 \x01(\x0c\"\x8e\x01\n\rDeviceRequest\x12\x15\n\rclientVersion\x18\x01 \x01(\t\x12\x12\n\ndeviceName\x18\x02 \x01(\t\x12\x16\n\x0e\x64\x65vicePlatform\x18\x03 \x01(\t\x12:\n\x10\x63lientFormFactor\x18\x04 \x01(\x0e\x32 .Authentication.ClientFormFactor\"T\n\x0b\x41uthRequest\x12\x15\n\rclientVersion\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x03 \x01(\x0c\"\xc3\x01\n\x14NewUserMinimumParams\x12\x19\n\x11minimumIterations\x18\x01 \x01(\x05\x12\x1a\n\x12passwordMatchRegex\x18\x02 \x03(\t\x12 \n\x18passwordMatchDescription\x18\x03 \x03(\t\x12\x1a\n\x12isEnterpriseDomain\x18\x04 \x01(\x08\x12\x1e\n\x16\x65nterpriseEccPublicKey\x18\x05 \x01(\x0c\x12\x16\n\x0e\x66orbidKeyType2\x18\x06 \x01(\x08\"\x89\x01\n\x0fPreLoginRequest\x12\x30\n\x0b\x61uthRequest\x18\x01 \x01(\x0b\x32\x1b.Authentication.AuthRequest\x12,\n\tloginType\x18\x02 \x01(\x0e\x32\x19.Authentication.LoginType\x12\x16\n\x0etwoFactorToken\x18\x03 \x01(\x0c\"\x80\x02\n\x0cLoginRequest\x12\x30\n\x0b\x61uthRequest\x18\x01 \x01(\x0b\x32\x1b.Authentication.AuthRequest\x12,\n\tloginType\x18\x02 \x01(\x0e\x32\x19.Authentication.LoginType\x12\x1f\n\x17\x61uthenticationHashPrime\x18\x03 \x01(\x0c\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x04 \x01(\x0c\x12\x14\n\x0c\x61uthResponse\x18\x05 \x01(\x0c\x12\x16\n\x0emcEnterpriseId\x18\x06 \x01(\x05\x12\x12\n\npush_token\x18\x07 \x01(\t\x12\x10\n\x08platform\x18\x08 \x01(\t\"\\\n\x0e\x44\x65viceResponse\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x01 \x01(\x0c\x12,\n\x06status\x18\x02 \x01(\x0e\x32\x1c.Authentication.DeviceStatus\"V\n\x04Salt\x12\x12\n\niterations\x18\x01 \x01(\x05\x12\x0c\n\x04salt\x18\x02 \x01(\x0c\x12\x11\n\talgorithm\x18\x03 \x01(\x05\x12\x0b\n\x03uid\x18\x04 \x01(\x0c\x12\x0c\n\x04name\x18\x05 \x01(\t\" \n\x10TwoFactorChannel\x12\x0c\n\x04type\x18\x01 \x01(\x05\"\xfc\x02\n\x11StartLoginRequest\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x01 \x01(\x0c\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x15\n\rclientVersion\x18\x03 \x01(\t\x12\x19\n\x11messageSessionUid\x18\x04 \x01(\x0c\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x05 \x01(\x0c\x12,\n\tloginType\x18\x06 \x01(\x0e\x32\x19.Authentication.LoginType\x12\x16\n\x0emcEnterpriseId\x18\x07 \x01(\x05\x12\x30\n\x0bloginMethod\x18\x08 \x01(\x0e\x32\x1b.Authentication.LoginMethod\x12\x15\n\rforceNewLogin\x18\t \x01(\x08\x12\x11\n\tcloneCode\x18\n \x01(\x0c\x12\x18\n\x10v2TwoFactorToken\x18\x0b \x01(\t\x12\x12\n\naccountUid\x18\x0c \x01(\x0c\x12\x18\n\x10\x66romSessionToken\x18\r \x01(\x0c\"\xa7\x04\n\rLoginResponse\x12.\n\nloginState\x18\x01 \x01(\x0e\x32\x1a.Authentication.LoginState\x12\x12\n\naccountUid\x18\x02 \x01(\x0c\x12\x17\n\x0fprimaryUsername\x18\x03 \x01(\t\x12\x18\n\x10\x65ncryptedDataKey\x18\x04 \x01(\x0c\x12\x42\n\x14\x65ncryptedDataKeyType\x18\x05 \x01(\x0e\x32$.Authentication.EncryptedDataKeyType\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x06 \x01(\x0c\x12\x1d\n\x15\x65ncryptedSessionToken\x18\x07 \x01(\x0c\x12:\n\x10sessionTokenType\x18\x08 \x01(\x0e\x32 .Authentication.SessionTokenType\x12\x0f\n\x07message\x18\t \x01(\t\x12\x0b\n\x03url\x18\n \x01(\t\x12\x36\n\x08\x63hannels\x18\x0b \x03(\x0b\x32$.Authentication.TwoFactorChannelInfo\x12\"\n\x04salt\x18\x0c \x03(\x0b\x32\x14.Authentication.Salt\x12\x11\n\tcloneCode\x18\r \x01(\x0c\x12\x1a\n\x12stateSpecificValue\x18\x0e \x01(\t\x12\x18\n\x10ssoClientVersion\x18\x0f \x01(\t\x12 \n\x18sessionTokenTypeModifier\x18\x10 \x01(\t\"_\n\x11SwitchListElement\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08\x66ullName\x18\x02 \x01(\t\x12\x14\n\x0c\x61uthRequired\x18\x03 \x01(\x08\x12\x10\n\x08isLinked\x18\x04 \x01(\x08\"I\n\x12SwitchListResponse\x12\x33\n\x08\x65lements\x18\x01 \x03(\x0b\x32!.Authentication.SwitchListElement\"\x8c\x01\n\x0bSsoUserInfo\x12\x13\n\x0b\x63ompanyName\x18\x01 \x01(\t\x12\x13\n\x0bsamlRequest\x18\x02 \x01(\t\x12\x17\n\x0fsamlRequestType\x18\x03 \x01(\t\x12\x15\n\rssoDomainName\x18\x04 \x01(\t\x12\x10\n\x08loginUrl\x18\x05 \x01(\t\x12\x11\n\tlogoutUrl\x18\x06 \x01(\t\"\xd6\x01\n\x10PreLoginResponse\x12\x32\n\x0c\x64\x65viceStatus\x18\x01 \x01(\x0e\x32\x1c.Authentication.DeviceStatus\x12\"\n\x04salt\x18\x02 \x03(\x0b\x32\x14.Authentication.Salt\x12\x38\n\x0eOBSOLETE_FIELD\x18\x03 \x03(\x0b\x32 .Authentication.TwoFactorChannel\x12\x30\n\x0bssoUserInfo\x18\x04 \x01(\x0b\x32\x1b.Authentication.SsoUserInfo\"&\n\x12LoginAsUserRequest\x12\x10\n\x08username\x18\x01 \x01(\t\"W\n\x13LoginAsUserResponse\x12\x1d\n\x15\x65ncryptedSessionToken\x18\x01 \x01(\x0c\x12!\n\x19\x65ncryptedSharedAccountKey\x18\x02 \x01(\x0c\"\x84\x01\n\x17ValidateAuthHashRequest\x12\x36\n\x0epasswordMethod\x18\x01 \x01(\x0e\x32\x1e.Authentication.PasswordMethod\x12\x14\n\x0c\x61uthResponse\x18\x02 \x01(\x0c\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x03 \x01(\x0c\"\xc4\x02\n\x14TwoFactorChannelInfo\x12\x39\n\x0b\x63hannelType\x18\x01 \x01(\x0e\x32$.Authentication.TwoFactorChannelType\x12\x13\n\x0b\x63hannel_uid\x18\x02 \x01(\x0c\x12\x13\n\x0b\x63hannelName\x18\x03 \x01(\t\x12\x11\n\tchallenge\x18\x04 \x01(\t\x12\x14\n\x0c\x63\x61pabilities\x18\x05 \x03(\t\x12\x13\n\x0bphoneNumber\x18\x06 \x01(\t\x12:\n\rmaxExpiration\x18\x07 \x01(\x0e\x32#.Authentication.TwoFactorExpiration\x12\x11\n\tcreatedOn\x18\x08 \x01(\x03\x12:\n\rlastFrequency\x18\t \x01(\x0e\x32#.Authentication.TwoFactorExpiration\"d\n\x12TwoFactorDuoStatus\x12\x14\n\x0c\x63\x61pabilities\x18\x01 \x03(\t\x12\x13\n\x0bphoneNumber\x18\x02 \x01(\t\x12\x12\n\nenroll_url\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\"\xc7\x01\n\x13TwoFactorAddRequest\x12\x39\n\x0b\x63hannelType\x18\x01 \x01(\x0e\x32$.Authentication.TwoFactorChannelType\x12\x13\n\x0b\x63hannel_uid\x18\x02 \x01(\x0c\x12\x13\n\x0b\x63hannelName\x18\x03 \x01(\t\x12\x13\n\x0bphoneNumber\x18\x04 \x01(\t\x12\x36\n\x0b\x64uoPushType\x18\x05 \x01(\x0e\x32!.Authentication.TwoFactorPushType\"B\n\x16TwoFactorRenameRequest\x12\x13\n\x0b\x63hannel_uid\x18\x01 \x01(\x0c\x12\x13\n\x0b\x63hannelName\x18\x02 \x01(\t\"=\n\x14TwoFactorAddResponse\x12\x11\n\tchallenge\x18\x01 \x01(\t\x12\x12\n\nbackupKeys\x18\x02 \x03(\t\"-\n\x16TwoFactorDeleteRequest\x12\x13\n\x0b\x63hannel_uid\x18\x01 \x01(\x0c\"a\n\x15TwoFactorListResponse\x12\x36\n\x08\x63hannels\x18\x01 \x03(\x0b\x32$.Authentication.TwoFactorChannelInfo\x12\x10\n\x08\x65xpireOn\x18\x02 \x01(\x03\"Y\n TwoFactorUpdateExpirationRequest\x12\x35\n\x08\x65xpireIn\x18\x01 \x01(\x0e\x32#.Authentication.TwoFactorExpiration\"\xc9\x01\n\x18TwoFactorValidateRequest\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x01 \x01(\x0c\x12\x35\n\tvalueType\x18\x02 \x01(\x0e\x32\".Authentication.TwoFactorValueType\x12\r\n\x05value\x18\x03 \x01(\t\x12\x13\n\x0b\x63hannel_uid\x18\x04 \x01(\x0c\x12\x35\n\x08\x65xpireIn\x18\x05 \x01(\x0e\x32#.Authentication.TwoFactorExpiration\"8\n\x19TwoFactorValidateResponse\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x01 \x01(\x0c\"\xb8\x01\n\x18TwoFactorSendPushRequest\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x01 \x01(\x0c\x12\x33\n\x08pushType\x18\x02 \x01(\x0e\x32!.Authentication.TwoFactorPushType\x12\x13\n\x0b\x63hannel_uid\x18\x03 \x01(\x0c\x12\x35\n\x08\x65xpireIn\x18\x04 \x01(\x0e\x32#.Authentication.TwoFactorExpiration\"\x83\x01\n\x07License\x12\x0f\n\x07\x63reated\x18\x01 \x01(\x03\x12\x12\n\nexpiration\x18\x02 \x01(\x03\x12\x34\n\rlicenseStatus\x18\x03 \x01(\x0e\x32\x1d.Authentication.LicenseStatus\x12\x0c\n\x04paid\x18\x04 \x01(\x08\x12\x0f\n\x07message\x18\x05 \x01(\t\"G\n\x0fOwnerlessRecord\x12\x11\n\trecordUid\x18\x01 \x01(\x0c\x12\x11\n\trecordKey\x18\x02 \x01(\x0c\x12\x0e\n\x06status\x18\x03 \x01(\x05\"L\n\x10OwnerlessRecords\x12\x38\n\x0fownerlessRecord\x18\x01 \x03(\x0b\x32\x1f.Authentication.OwnerlessRecord\"\xd7\x01\n\x0fUserAuthRequest\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\x12\x0c\n\x04salt\x18\x02 \x01(\x0c\x12\x12\n\niterations\x18\x03 \x01(\x05\x12\x1a\n\x12\x65ncryptedClientKey\x18\x04 \x01(\x0c\x12\x10\n\x08\x61uthHash\x18\x05 \x01(\x0c\x12\x18\n\x10\x65ncryptedDataKey\x18\x06 \x01(\x0c\x12,\n\tloginType\x18\x07 \x01(\x0e\x32\x19.Authentication.LoginType\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x11\n\talgorithm\x18\t \x01(\x05\"\x19\n\nUidRequest\x12\x0b\n\x03uid\x18\x01 \x03(\x0c\"\xff\x01\n\x13\x44\x65viceUpdateRequest\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x01 \x01(\x0c\x12\x15\n\rclientVersion\x18\x02 \x01(\t\x12\x12\n\ndeviceName\x18\x03 \x01(\t\x12\x17\n\x0f\x64\x65vicePublicKey\x18\x04 \x01(\x0c\x12\x32\n\x0c\x64\x65viceStatus\x18\x05 \x01(\x0e\x32\x1c.Authentication.DeviceStatus\x12\x16\n\x0e\x64\x65vicePlatform\x18\x06 \x01(\t\x12:\n\x10\x63lientFormFactor\x18\x07 \x01(\x0e\x32 .Authentication.ClientFormFactor\"\xd5\x01\n\x1dRegisterDeviceInRegionRequest\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x01 \x01(\x0c\x12\x15\n\rclientVersion\x18\x02 \x01(\t\x12\x12\n\ndeviceName\x18\x03 \x01(\t\x12\x17\n\x0f\x64\x65vicePublicKey\x18\x04 \x01(\x0c\x12\x16\n\x0e\x64\x65vicePlatform\x18\x05 \x01(\t\x12:\n\x10\x63lientFormFactor\x18\x06 \x01(\x0e\x32 .Authentication.ClientFormFactor\"\xf8\x02\n\x13RegistrationRequest\x12\x30\n\x0b\x61uthRequest\x18\x01 \x01(\x0b\x32\x1b.Authentication.AuthRequest\x12\x38\n\x0fuserAuthRequest\x18\x02 \x01(\x0b\x32\x1f.Authentication.UserAuthRequest\x12\x1a\n\x12\x65ncryptedClientKey\x18\x03 \x01(\x0c\x12\x1b\n\x13\x65ncryptedPrivateKey\x18\x04 \x01(\x0c\x12\x11\n\tpublicKey\x18\x05 \x01(\x0c\x12\x18\n\x10verificationCode\x18\x06 \x01(\t\x12\x1e\n\x16\x64\x65precatedAuthHashHash\x18\x07 \x01(\x0c\x12$\n\x1c\x64\x65precatedEncryptedClientKey\x18\x08 \x01(\x0c\x12%\n\x1d\x64\x65precatedEncryptedPrivateKey\x18\t \x01(\x0c\x12\"\n\x1a\x64\x65precatedEncryptionParams\x18\n \x01(\x0c\"\xd0\x01\n\x16\x43onvertUserToV3Request\x12\x30\n\x0b\x61uthRequest\x18\x01 \x01(\x0b\x32\x1b.Authentication.AuthRequest\x12\x38\n\x0fuserAuthRequest\x18\x02 \x01(\x0b\x32\x1f.Authentication.UserAuthRequest\x12\x1a\n\x12\x65ncryptedClientKey\x18\x03 \x01(\x0c\x12\x1b\n\x13\x65ncryptedPrivateKey\x18\x04 \x01(\x0c\x12\x11\n\tpublicKey\x18\x05 \x01(\x0c\"$\n\x10RevisionResponse\x12\x10\n\x08revision\x18\x01 \x01(\x03\"&\n\x12\x43hangeEmailRequest\x12\x10\n\x08newEmail\x18\x01 \x01(\t\"8\n\x13\x43hangeEmailResponse\x12!\n\x19\x65ncryptedChangeEmailToken\x18\x01 \x01(\x0c\"6\n\x1d\x45mailVerificationLinkResponse\x12\x15\n\remailVerified\x18\x01 \x01(\x08\")\n\x0cSecurityData\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"@\n\x11SecurityScoreData\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x10\n\x08revision\x18\x03 \x01(\x03\"\x8b\x02\n\x13SecurityDataRequest\x12\x38\n\x12recordSecurityData\x18\x01 \x03(\x0b\x32\x1c.Authentication.SecurityData\x12@\n\x1amasterPasswordSecurityData\x18\x02 \x03(\x0b\x32\x1c.Authentication.SecurityData\x12\x34\n\x0e\x65ncryptionType\x18\x03 \x01(\x0e\x32\x1c.Enterprise.EncryptedKeyType\x12\x42\n\x17recordSecurityScoreData\x18\x04 \x03(\x0b\x32!.Authentication.SecurityScoreData\"\xb3\x02\n\x1dSecurityReportIncrementalData\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x1b\n\x13\x63urrentSecurityData\x18\x02 \x01(\x0c\x12#\n\x1b\x63urrentSecurityDataRevision\x18\x03 \x01(\x03\x12\x17\n\x0foldSecurityData\x18\x04 \x01(\x0c\x12\x1f\n\x17oldSecurityDataRevision\x18\x05 \x01(\x03\x12?\n\x19\x63urrentDataEncryptionType\x18\x06 \x01(\x0e\x32\x1c.Enterprise.EncryptedKeyType\x12;\n\x15oldDataEncryptionType\x18\x07 \x01(\x0e\x32\x1c.Enterprise.EncryptedKeyType\"\x9f\x02\n\x0eSecurityReport\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x1b\n\x13\x65ncryptedReportData\x18\x02 \x01(\x0c\x12\x10\n\x08revision\x18\x03 \x01(\x03\x12\x11\n\ttwoFactor\x18\x04 \x01(\t\x12\x11\n\tlastLogin\x18\x05 \x01(\x03\x12\x1e\n\x16numberOfReusedPassword\x18\x06 \x01(\x05\x12T\n\x1dsecurityReportIncrementalData\x18\x07 \x03(\x0b\x32-.Authentication.SecurityReportIncrementalData\x12\x0e\n\x06userId\x18\x08 \x01(\x05\x12\x18\n\x10hasOldEncryption\x18\t \x01(\x08\"S\n\x19SecurityReportSaveRequest\x12\x36\n\x0esecurityReport\x18\x01 \x03(\x0b\x32\x1e.Authentication.SecurityReport\")\n\x15SecurityReportRequest\x12\x10\n\x08\x66romPage\x18\x01 \x01(\x03\"\xd9\x01\n\x16SecurityReportResponse\x12\x1c\n\x14\x65nterprisePrivateKey\x18\x01 \x01(\x0c\x12\x36\n\x0esecurityReport\x18\x02 \x03(\x0b\x32\x1e.Authentication.SecurityReport\x12\x14\n\x0c\x61sOfRevision\x18\x03 \x01(\x03\x12\x10\n\x08\x66romPage\x18\x04 \x01(\x03\x12\x0e\n\x06toPage\x18\x05 \x01(\x03\x12\x10\n\x08\x63omplete\x18\x06 \x01(\x08\x12\x1f\n\x17\x65nterpriseEccPrivateKey\x18\x07 \x01(\x0c\"\'\n\x16ReusedPasswordsRequest\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\">\n\x14SummaryConsoleReport\x12\x12\n\nreportType\x18\x01 \x01(\x05\x12\x12\n\nreportData\x18\x02 \x01(\x0c\"|\n\x12\x43hangeToKeyTypeOne\x12/\n\nobjectType\x18\x01 \x01(\x0e\x32\x1b.Authentication.ObjectTypes\x12\x12\n\nprimaryUid\x18\x02 \x01(\x0c\x12\x14\n\x0csecondaryUid\x18\x03 \x01(\x0c\x12\x0b\n\x03key\x18\x04 \x01(\x0c\"[\n\x19\x43hangeToKeyTypeOneRequest\x12>\n\x12\x63hangeToKeyTypeOne\x18\x01 \x03(\x0b\x32\".Authentication.ChangeToKeyTypeOne\"U\n\x18\x43hangeToKeyTypeOneStatus\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\"h\n\x1a\x43hangeToKeyTypeOneResponse\x12J\n\x18\x63hangeToKeyTypeOneStatus\x18\x01 \x03(\x0b\x32(.Authentication.ChangeToKeyTypeOneStatus\"\xb9\x01\n\x18GetChangeKeyTypesRequest\x12=\n\x10onlyTheseObjects\x18\x01 \x03(\x0e\x32#.Authentication.EncryptedObjectType\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x1a\n\x12includeRecommended\x18\x03 \x01(\x08\x12\x13\n\x0bincludeKeys\x18\x04 \x01(\x08\x12\x1e\n\x16includeAllowedKeyTypes\x18\x05 \x01(\x08\"\x82\x01\n\x19GetChangeKeyTypesResponse\x12+\n\x04keys\x18\x01 \x03(\x0b\x32\x1d.Authentication.ChangeKeyType\x12\x38\n\x0f\x61llowedKeyTypes\x18\x02 \x03(\x0b\x32\x1f.Authentication.AllowedKeyTypes\"\x81\x01\n\x0f\x41llowedKeyTypes\x12\x37\n\nobjectType\x18\x01 \x01(\x0e\x32#.Authentication.EncryptedObjectType\x12\x35\n\x0f\x61llowedKeyTypes\x18\x02 \x03(\x0e\x32\x1c.Enterprise.EncryptedKeyType\"=\n\x0e\x43hangeKeyTypes\x12+\n\x04keys\x18\x01 \x03(\x0b\x32\x1d.Authentication.ChangeKeyType\"\xd6\x01\n\rChangeKeyType\x12\x37\n\nobjectType\x18\x01 \x01(\x0e\x32#.Authentication.EncryptedObjectType\x12\x0b\n\x03uid\x18\x02 \x01(\x0c\x12\x14\n\x0csecondaryUid\x18\x03 \x01(\x0c\x12\x0b\n\x03key\x18\x04 \x01(\x0c\x12-\n\x07keyType\x18\x05 \x01(\x0e\x32\x1c.Enterprise.EncryptedKeyType\x12-\n\x06status\x18\x06 \x01(\x0e\x32\x1d.Authentication.GenericStatus\"!\n\x06SetKey\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03key\x18\x02 \x01(\x0c\"5\n\rSetKeyRequest\x12$\n\x04keys\x18\x01 \x03(\x0b\x32\x16.Authentication.SetKey\"\x92\x05\n\x11\x43reateUserRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x14\n\x0c\x61uthVerifier\x18\x02 \x01(\x0c\x12\x18\n\x10\x65ncryptionParams\x18\x03 \x01(\x0c\x12\x14\n\x0crsaPublicKey\x18\x04 \x01(\x0c\x12\x1e\n\x16rsaEncryptedPrivateKey\x18\x05 \x01(\x0c\x12\x14\n\x0c\x65\x63\x63PublicKey\x18\x06 \x01(\x0c\x12\x1e\n\x16\x65\x63\x63\x45ncryptedPrivateKey\x18\x07 \x01(\x0c\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x08 \x01(\x0c\x12\x1a\n\x12\x65ncryptedClientKey\x18\t \x01(\x0c\x12\x15\n\rclientVersion\x18\n \x01(\t\x12\x1e\n\x16\x65ncryptedDeviceDataKey\x18\x0b \x01(\x0c\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x0c \x01(\x0c\x12\x19\n\x11messageSessionUid\x18\r \x01(\x0c\x12\x17\n\x0finstallReferrer\x18\x0e \x01(\t\x12\x0e\n\x06mccMNC\x18\x0f \x01(\x05\x12\x0b\n\x03mfg\x18\x10 \x01(\t\x12\r\n\x05model\x18\x11 \x01(\t\x12\r\n\x05\x62rand\x18\x12 \x01(\t\x12\x0f\n\x07product\x18\x13 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x14 \x01(\t\x12\x0f\n\x07\x63\x61rrier\x18\x15 \x01(\t\x12\x18\n\x10verificationCode\x18\x16 \x01(\t\x12\x42\n\x16\x65nterpriseRegistration\x18\x17 \x01(\x0b\x32\".Enterprise.EnterpriseRegistration\x12\"\n\x1a\x65ncryptedVerificationToken\x18\x18 \x01(\x0c\x12\x1e\n\x16\x65nterpriseUsersDataKey\x18\x19 \x01(\x0c\"W\n!NodeEnforcementAddOrUpdateRequest\x12\x0e\n\x06nodeId\x18\x01 \x01(\x03\x12\x13\n\x0b\x65nforcement\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"C\n\x1cNodeEnforcementRemoveRequest\x12\x0e\n\x06nodeId\x18\x01 \x01(\x03\x12\x13\n\x0b\x65nforcement\x18\x02 \x01(\t\"\x9f\x01\n\x0f\x41piRequestByKey\x12\r\n\x05keyId\x18\x01 \x01(\x05\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12\x10\n\x08username\x18\x03 \x01(\t\x12\x0e\n\x06locale\x18\x04 \x01(\t\x12<\n\x11supportedLanguage\x18\x05 \x01(\x0e\x32!.Authentication.SupportedLanguage\x12\x0c\n\x04type\x18\x06 \x01(\x05\"\xc7\x01\n\x15\x41piRequestByKAtoKAKey\x12,\n\x0csourceRegion\x18\x01 \x01(\x0e\x32\x16.Authentication.Region\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12<\n\x11supportedLanguage\x18\x03 \x01(\x0e\x32!.Authentication.SupportedLanguage\x12\x31\n\x11\x64\x65stinationRegion\x18\x04 \x01(\x0e\x32\x16.Authentication.Region\".\n\x0fMemcacheRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0e\n\x06userId\x18\x02 \x01(\x05\".\n\x10MemcacheResponse\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"w\n\x1cMasterPasswordReentryRequest\x12\x16\n\x0epbkdf2Password\x18\x01 \x01(\t\x12?\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32/.Authentication.MasterPasswordReentryActionType\"\\\n\x1dMasterPasswordReentryResponse\x12;\n\x06status\x18\x01 \x01(\x0e\x32+.Authentication.MasterPasswordReentryStatus\"\xb3\x01\n\x19\x44\x65viceRegistrationRequest\x12\x15\n\rclientVersion\x18\x01 \x01(\t\x12\x12\n\ndeviceName\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x65vicePublicKey\x18\x03 \x01(\x0c\x12\x16\n\x0e\x64\x65vicePlatform\x18\x04 \x01(\t\x12:\n\x10\x63lientFormFactor\x18\x05 \x01(\x0e\x32 .Authentication.ClientFormFactor\"\x9a\x01\n\x19\x44\x65viceVerificationRequest\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x01 \x01(\x0c\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x1b\n\x13verificationChannel\x18\x03 \x01(\t\x12\x19\n\x11messageSessionUid\x18\x04 \x01(\x0c\x12\x15\n\rclientVersion\x18\x05 \x01(\t\"\xb2\x01\n\x1a\x44\x65viceVerificationResponse\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x01 \x01(\x0c\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x19\n\x11messageSessionUid\x18\x03 \x01(\x0c\x12\x15\n\rclientVersion\x18\x04 \x01(\t\x12\x32\n\x0c\x64\x65viceStatus\x18\x05 \x01(\x0e\x32\x1c.Authentication.DeviceStatus\"\xc8\x01\n\x15\x44\x65viceApprovalRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x18\n\x10twoFactorChannel\x18\x02 \x01(\t\x12\x15\n\rclientVersion\x18\x03 \x01(\t\x12\x0e\n\x06locale\x18\x04 \x01(\t\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x05 \x01(\x0c\x12\x10\n\x08totpCode\x18\x06 \x01(\t\x12\x10\n\x08\x64\x65viceIp\x18\x07 \x01(\t\x12\x1d\n\x15\x64\x65viceTokenExpireDays\x18\x08 \x01(\t\"9\n\x16\x44\x65viceApprovalResponse\x12\x1f\n\x17\x65ncryptedTwoFactorToken\x18\x01 \x01(\x0c\"~\n\x14\x41pproveDeviceRequest\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x01 \x01(\x0c\x12\x1e\n\x16\x65ncryptedDeviceDataKey\x18\x02 \x01(\x0c\x12\x14\n\x0c\x64\x65nyApproval\x18\x03 \x01(\x08\x12\x12\n\nlinkDevice\x18\x04 \x01(\x08\"E\n\x1a\x45nterpriseUserAliasRequest\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\r\n\x05\x61lias\x18\x02 \x01(\t\"Y\n\x1d\x45nterpriseUserAddAliasRequest\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\r\n\x05\x61lias\x18\x02 \x01(\t\x12\x0f\n\x07primary\x18\x03 \x01(\x08\"w\n\x1f\x45nterpriseUserAddAliasRequestV2\x12T\n\x1d\x65nterpriseUserAddAliasRequest\x18\x01 \x03(\x0b\x32-.Authentication.EnterpriseUserAddAliasRequest\"H\n\x1c\x45nterpriseUserAddAliasStatus\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x0e\n\x06status\x18\x02 \x01(\t\"^\n\x1e\x45nterpriseUserAddAliasResponse\x12<\n\x06status\x18\x01 \x03(\x0b\x32,.Authentication.EnterpriseUserAddAliasStatus\"&\n\x06\x44\x65vice\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x01 \x01(\x0c\"\\\n\x1cRegisterDeviceDataKeyRequest\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x01 \x01(\x0c\x12\x1e\n\x16\x65ncryptedDeviceDataKey\x18\x02 \x01(\x0c\"n\n)ValidateCreateUserVerificationCodeRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x15\n\rclientVersion\x18\x02 \x01(\t\x12\x18\n\x10verificationCode\x18\x03 \x01(\t\"\xa3\x01\n%ValidateDeviceVerificationCodeRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x15\n\rclientVersion\x18\x02 \x01(\t\x12\x18\n\x10verificationCode\x18\x03 \x01(\t\x12\x19\n\x11messageSessionUid\x18\x04 \x01(\x0c\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x05 \x01(\x0c\"Y\n\x19SendSessionMessageRequest\x12\x19\n\x11messageSessionUid\x18\x01 \x01(\x0c\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\t\x12\x10\n\x08username\x18\x03 \x01(\t\"M\n\x11GlobalUserAccount\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x12\n\naccountUid\x18\x02 \x01(\x0c\x12\x12\n\nregionName\x18\x03 \x01(\t\"7\n\x0f\x41\x63\x63ountUsername\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x12\n\ndateActive\x18\x02 \x01(\t\"P\n\x19SsoServiceProviderRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rclientVersion\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x03 \x01(\t\"a\n\x1aSsoServiceProviderResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05spUrl\x18\x02 \x01(\t\x12\x0f\n\x07isCloud\x18\x03 \x01(\x08\x12\x15\n\rclientVersion\x18\x04 \x01(\t\"4\n\x12UserSettingRequest\x12\x0f\n\x07setting\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"f\n\rThrottleState\x12*\n\x04type\x18\x01 \x01(\x0e\x32\x1c.Authentication.ThrottleType\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\x08\"\xb5\x01\n\x0eThrottleState2\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x16\n\x0ekeyDescription\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\x18\n\x10valueDescription\x18\x04 \x01(\t\x12\x12\n\nidentifier\x18\x05 \x01(\t\x12\x0e\n\x06locked\x18\x06 \x01(\x08\x12\x1a\n\x12includedInAllClear\x18\x07 \x01(\x08\x12\x15\n\rexpireSeconds\x18\x08 \x01(\x05\"\x97\x01\n\x11\x44\x65viceInformation\x12\x10\n\x08\x64\x65viceId\x18\x01 \x01(\x03\x12\x12\n\ndeviceName\x18\x02 \x01(\t\x12\x15\n\rclientVersion\x18\x03 \x01(\t\x12\x11\n\tlastLogin\x18\x04 \x01(\x03\x12\x32\n\x0c\x64\x65viceStatus\x18\x05 \x01(\x0e\x32\x1c.Authentication.DeviceStatus\"*\n\x0bUserSetting\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08\".\n\x12UserDataKeyRequest\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x03(\x03\"+\n\x18UserDataKeyByNodeRequest\x12\x0f\n\x07nodeIds\x18\x01 \x03(\x03\"\x80\x01\n\x1b\x45nterpriseUserIdDataKeyPair\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x18\n\x10\x65ncryptedDataKey\x18\x02 \x01(\x0c\x12-\n\x07keyType\x18\x03 \x01(\x0e\x32\x1c.Enterprise.EncryptedKeyType\"\x95\x01\n\x0bUserDataKey\x12\x0e\n\x06roleId\x18\x01 \x01(\x03\x12\x0f\n\x07roleKey\x18\x02 \x01(\x0c\x12\x12\n\nprivateKey\x18\x03 \x01(\t\x12Q\n\x1c\x65nterpriseUserIdDataKeyPairs\x18\x04 \x03(\x0b\x32+.Authentication.EnterpriseUserIdDataKeyPair\"z\n\x13UserDataKeyResponse\x12\x31\n\x0cuserDataKeys\x18\x01 \x03(\x0b\x32\x1b.Authentication.UserDataKey\x12\x14\n\x0c\x61\x63\x63\x65ssDenied\x18\x02 \x03(\x03\x12\x1a\n\x12noEncryptedDataKey\x18\x03 \x03(\x03\"H\n)MasterPasswordRecoveryVerificationRequest\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x01 \x01(\x0c\"U\n\x1cGetSecurityQuestionV3Request\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x01 \x01(\x0c\x12\x18\n\x10verificationCode\x18\x02 \x01(\t\"r\n\x1dGetSecurityQuestionV3Response\x12\x18\n\x10securityQuestion\x18\x01 \x01(\t\x12\x15\n\rbackupKeyDate\x18\x02 \x01(\x03\x12\x0c\n\x04salt\x18\x03 \x01(\x0c\x12\x12\n\niterations\x18\x04 \x01(\x05\"n\n\x19GetDataKeyBackupV3Request\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x01 \x01(\x0c\x12\x18\n\x10verificationCode\x18\x02 \x01(\t\x12\x1a\n\x12securityAnswerHash\x18\x03 \x01(\x0c\"v\n\rPasswordRules\x12\x10\n\x08ruleType\x18\x01 \x01(\t\x12\r\n\x05match\x18\x02 \x01(\x08\x12\x0f\n\x07pattern\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0f\n\x07minimum\x18\x05 \x01(\x05\x12\r\n\x05value\x18\x06 \x01(\t\"\xc9\x02\n\x1aGetDataKeyBackupV3Response\x12\x15\n\rdataKeyBackup\x18\x01 \x01(\x0c\x12\x19\n\x11\x64\x61taKeyBackupDate\x18\x02 \x01(\x03\x12\x11\n\tpublicKey\x18\x03 \x01(\x0c\x12\x1b\n\x13\x65ncryptedPrivateKey\x18\x04 \x01(\x0c\x12\x11\n\tclientKey\x18\x05 \x01(\x0c\x12\x1d\n\x15\x65ncryptedSessionToken\x18\x06 \x01(\x0c\x12\x34\n\rpasswordRules\x18\x07 \x03(\x0b\x32\x1d.Authentication.PasswordRules\x12\x1a\n\x12passwordRulesIntro\x18\x08 \x01(\t\x12\x1f\n\x17minimumPbkdf2Iterations\x18\t \x01(\x05\x12$\n\x07keyType\x18\n \x01(\x0e\x32\x13.Enterprise.KeyType\")\n\x14GetPublicKeysRequest\x12\x11\n\tusernames\x18\x01 \x03(\t\"r\n\x11PublicKeyResponse\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x11\n\tpublicKey\x18\x02 \x01(\x0c\x12\x14\n\x0cpublicEccKey\x18\x03 \x01(\x0c\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x11\n\terrorCode\x18\x05 \x01(\t\"P\n\x15GetPublicKeysResponse\x12\x37\n\x0ckeyResponses\x18\x01 \x03(\x0b\x32!.Authentication.PublicKeyResponse\"F\n\x14SetEccKeyPairRequest\x12\x11\n\tpublicKey\x18\x01 \x01(\x0c\x12\x1b\n\x13\x65ncryptedPrivateKey\x18\x02 \x01(\x0c\"I\n\x15SetEccKeyPairsRequest\x12\x30\n\x08teamKeys\x18\x01 \x03(\x0b\x32\x1e.Authentication.TeamEccKeyPair\"R\n\x16SetEccKeyPairsResponse\x12\x38\n\x08teamKeys\x18\x01 \x03(\x0b\x32&.Authentication.TeamEccKeyPairResponse\"Q\n\x0eTeamEccKeyPair\x12\x0f\n\x07teamUid\x18\x01 \x01(\x0c\x12\x11\n\tpublicKey\x18\x02 \x01(\x0c\x12\x1b\n\x13\x65ncryptedPrivateKey\x18\x03 \x01(\x0c\"X\n\x16TeamEccKeyPairResponse\x12\x0f\n\x07teamUid\x18\x01 \x01(\x0c\x12-\n\x06status\x18\x02 \x01(\x0e\x32\x1d.Authentication.GenericStatus\"D\n\x17GetKsmPublicKeysRequest\x12\x11\n\tclientIds\x18\x01 \x03(\x0c\x12\x16\n\x0e\x63ontrollerUids\x18\x02 \x03(\x0c\"U\n\x17\x44\x65vicePublicKeyResponse\x12\x10\n\x08\x63lientId\x18\x01 \x01(\x0c\x12\x11\n\tpublicKey\x18\x02 \x01(\x0c\x12\x15\n\rcontrollerUid\x18\x03 \x01(\x0c\"Y\n\x18GetKsmPublicKeysResponse\x12=\n\x0ckeyResponses\x18\x01 \x03(\x0b\x32\'.Authentication.DevicePublicKeyResponse\"X\n\x13\x41\x64\x64\x41ppSharesRequest\x12\x14\n\x0c\x61ppRecordUid\x18\x01 \x01(\x0c\x12+\n\x06shares\x18\x02 \x03(\x0b\x32\x1b.Authentication.AppShareAdd\">\n\x16RemoveAppSharesRequest\x12\x14\n\x0c\x61ppRecordUid\x18\x01 \x01(\x0c\x12\x0e\n\x06shares\x18\x02 \x03(\x0c\"\x87\x01\n\x0b\x41ppShareAdd\x12\x11\n\tsecretUid\x18\x02 \x01(\x0c\x12\x37\n\tshareType\x18\x03 \x01(\x0e\x32$.Authentication.ApplicationShareType\x12\x1a\n\x12\x65ncryptedSecretKey\x18\x04 \x01(\x0c\x12\x10\n\x08\x65\x64itable\x18\x05 \x01(\x08\"\x89\x01\n\x08\x41ppShare\x12\x11\n\tsecretUid\x18\x01 \x01(\x0c\x12\x37\n\tshareType\x18\x02 \x01(\x0e\x32$.Authentication.ApplicationShareType\x12\x10\n\x08\x65\x64itable\x18\x03 \x01(\x08\x12\x11\n\tcreatedOn\x18\x04 \x01(\x03\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c\"\xd9\x01\n\x13\x41\x64\x64\x41ppClientRequest\x12\x14\n\x0c\x61ppRecordUid\x18\x01 \x01(\x0c\x12\x17\n\x0f\x65ncryptedAppKey\x18\x02 \x01(\x0c\x12\x10\n\x08\x63lientId\x18\x03 \x01(\x0c\x12\x0e\n\x06lockIp\x18\x04 \x01(\x08\x12\x1b\n\x13\x66irstAccessExpireOn\x18\x05 \x01(\x03\x12\x16\n\x0e\x61\x63\x63\x65ssExpireOn\x18\x06 \x01(\x03\x12\n\n\x02id\x18\x07 \x01(\t\x12\x30\n\rappClientType\x18\x08 \x01(\x0e\x32\x19.Enterprise.AppClientType\"@\n\x17RemoveAppClientsRequest\x12\x14\n\x0c\x61ppRecordUid\x18\x01 \x01(\x0c\x12\x0f\n\x07\x63lients\x18\x02 \x03(\x0c\"\xaa\x01\n\x17\x41\x64\x64\x45xternalShareRequest\x12\x11\n\trecordUid\x18\x01 \x01(\x0c\x12\x1a\n\x12\x65ncryptedRecordKey\x18\x02 \x01(\x0c\x12\x10\n\x08\x63lientId\x18\x03 \x01(\x0c\x12\x16\n\x0e\x61\x63\x63\x65ssExpireOn\x18\x04 \x01(\x03\x12\n\n\x02id\x18\x05 \x01(\t\x12\x16\n\x0eisSelfDestruct\x18\x06 \x01(\x08\x12\x12\n\nisEditable\x18\x07 \x01(\x08\"\x93\x02\n\tAppClient\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x63lientId\x18\x02 \x01(\x0c\x12\x11\n\tcreatedOn\x18\x03 \x01(\x03\x12\x13\n\x0b\x66irstAccess\x18\x04 \x01(\x03\x12\x12\n\nlastAccess\x18\x05 \x01(\x03\x12\x11\n\tpublicKey\x18\x06 \x01(\x0c\x12\x0e\n\x06lockIp\x18\x07 \x01(\x08\x12\x11\n\tipAddress\x18\x08 \x01(\t\x12\x1b\n\x13\x66irstAccessExpireOn\x18\t \x01(\x03\x12\x16\n\x0e\x61\x63\x63\x65ssExpireOn\x18\n \x01(\x03\x12\x30\n\rappClientType\x18\x0b \x01(\x0e\x32\x19.Enterprise.AppClientType\x12\x0f\n\x07\x63\x61nEdit\x18\x0c \x01(\x08\")\n\x11GetAppInfoRequest\x12\x14\n\x0c\x61ppRecordUid\x18\x01 \x03(\x0c\"\x8e\x01\n\x07\x41ppInfo\x12\x14\n\x0c\x61ppRecordUid\x18\x01 \x01(\x0c\x12(\n\x06shares\x18\x02 \x03(\x0b\x32\x18.Authentication.AppShare\x12*\n\x07\x63lients\x18\x03 \x03(\x0b\x32\x19.Authentication.AppClient\x12\x17\n\x0fisExternalShare\x18\x04 \x01(\x08\">\n\x12GetAppInfoResponse\x12(\n\x07\x61ppInfo\x18\x01 \x03(\x0b\x32\x17.Authentication.AppInfo\"\xd5\x01\n\x12\x41pplicationSummary\x12\x14\n\x0c\x61ppRecordUid\x18\x01 \x01(\x0c\x12\x12\n\nlastAccess\x18\x02 \x01(\x03\x12\x14\n\x0crecordShares\x18\x03 \x01(\x05\x12\x14\n\x0c\x66olderShares\x18\x04 \x01(\x05\x12\x15\n\rfolderRecords\x18\x05 \x01(\x05\x12\x13\n\x0b\x63lientCount\x18\x06 \x01(\x05\x12\x1a\n\x12\x65xpiredClientCount\x18\x07 \x01(\x05\x12\x10\n\x08username\x18\x08 \x01(\t\x12\x0f\n\x07\x61ppData\x18\t \x01(\x0c\"`\n\x1eGetApplicationsSummaryResponse\x12>\n\x12\x61pplicationSummary\x18\x01 \x03(\x0b\x32\".Authentication.ApplicationSummary\"/\n\x1bGetVerificationTokenRequest\x12\x10\n\x08username\x18\x01 \x01(\t\"B\n\x1cGetVerificationTokenResponse\x12\"\n\x1a\x65ncryptedVerificationToken\x18\x01 \x01(\x0c\"\'\n\x16SendShareInviteRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"\xc5\x01\n\x18TimeLimitedAccessRequest\x12\x12\n\naccountUid\x18\x01 \x03(\x0c\x12\x0f\n\x07teamUid\x18\x02 \x03(\x0c\x12\x11\n\trecordUid\x18\x03 \x03(\x0c\x12\x17\n\x0fsharedObjectUid\x18\x04 \x01(\x0c\x12\x44\n\x15timeLimitedAccessType\x18\x05 \x01(\x0e\x32%.Authentication.TimeLimitedAccessType\x12\x12\n\nexpiration\x18\x06 \x01(\x03\"7\n\x17TimeLimitedAccessStatus\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xf8\x01\n\x19TimeLimitedAccessResponse\x12\x10\n\x08revision\x18\x01 \x01(\x03\x12\x41\n\x10userAccessStatus\x18\x02 \x03(\x0b\x32\'.Authentication.TimeLimitedAccessStatus\x12\x41\n\x10teamAccessStatus\x18\x03 \x03(\x0b\x32\'.Authentication.TimeLimitedAccessStatus\x12\x43\n\x12recordAccessStatus\x18\x04 \x03(\x0b\x32\'.Authentication.TimeLimitedAccessStatus\"+\n\x16RequestDownloadRequest\x12\x11\n\tfileNames\x18\x01 \x03(\t\"g\n\x17RequestDownloadResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12+\n\tdownloads\x18\x03 \x03(\x0b\x32\x18.Authentication.Download\"D\n\x08\x44ownload\x12\x10\n\x08\x66ileName\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x19\n\x11successStatusCode\x18\x03 \x01(\x05\"#\n\x11\x44\x65leteUserRequest\x12\x0e\n\x06reason\x18\x01 \x01(\t\"\x84\x01\n\x1b\x43hangeMasterPasswordRequest\x12\x14\n\x0c\x61uthVerifier\x18\x01 \x01(\x0c\x12\x18\n\x10\x65ncryptionParams\x18\x02 \x01(\x0c\x12\x1b\n\x13\x66romServiceProvider\x18\x03 \x01(\x08\x12\x18\n\x10iterationsChange\x18\x04 \x01(\x08\"=\n\x1c\x43hangeMasterPasswordResponse\x12\x1d\n\x15\x65ncryptedSessionToken\x18\x01 \x01(\x0c\"Y\n\x1b\x41\x63\x63ountRecoverySetupRequest\x12 \n\x18recoveryEncryptedDataKey\x18\x01 \x01(\x0c\x12\x18\n\x10recoveryAuthHash\x18\x02 \x01(\x0c\"\xac\x01\n!AccountRecoveryVerifyCodeResponse\x12\x34\n\rbackupKeyType\x18\x01 \x01(\x0e\x32\x1d.Authentication.BackupKeyType\x12\x15\n\rbackupKeyDate\x18\x02 \x01(\x03\x12\x18\n\x10securityQuestion\x18\x03 \x01(\t\x12\x0c\n\x04salt\x18\x04 \x01(\x0c\x12\x12\n\niterations\x18\x05 \x01(\x05\",\n\x1b\x45mergencyAccessLoginRequest\x12\r\n\x05owner\x18\x01 \x01(\t\"\xb5\x01\n\x1c\x45mergencyAccessLoginResponse\x12\x14\n\x0csessionToken\x18\x01 \x01(\x0c\x12%\n\x07\x64\x61taKey\x18\x02 \x01(\x0b\x32\x14.Enterprise.TypedKey\x12+\n\rrsaPrivateKey\x18\x03 \x01(\x0b\x32\x14.Enterprise.TypedKey\x12+\n\reccPrivateKey\x18\x04 \x01(\x0b\x32\x14.Enterprise.TypedKey\"\xb2\x01\n\x0bUserTeamKey\x12\x0f\n\x07teamUid\x18\x01 \x01(\x0c\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x18\n\x10\x65nterpriseUserId\x18\x03 \x01(\x03\x12\x1b\n\x13\x65ncryptedTeamKeyRSA\x18\x04 \x01(\x0c\x12\x1a\n\x12\x65ncryptedTeamKeyEC\x18\x05 \x01(\x0c\x12-\n\x06status\x18\x06 \x01(\x0e\x32\x1d.Authentication.GenericStatus\")\n\x16GenericRequestResponse\x12\x0f\n\x07request\x18\x01 \x03(\x0c\"f\n\x1aPasskeyRegistrationRequest\x12H\n\x17\x61uthenticatorAttachment\x18\x01 \x01(\x0e\x32\'.Authentication.AuthenticatorAttachment\"P\n\x1bPasskeyRegistrationResponse\x12\x16\n\x0e\x63hallengeToken\x18\x01 \x01(\x0c\x12\x19\n\x11pkCreationOptions\x18\x02 \x01(\t\"\x84\x01\n\x1fPasskeyRegistrationFinalization\x12\x16\n\x0e\x63hallengeToken\x18\x01 \x01(\x0c\x12\x1d\n\x15\x61uthenticatorResponse\x18\x02 \x01(\t\x12\x19\n\x0c\x66riendlyName\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_friendlyName\"\xb3\x02\n\x1cPasskeyAuthenticationRequest\x12H\n\x17\x61uthenticatorAttachment\x18\x01 \x01(\x0e\x32\'.Authentication.AuthenticatorAttachment\x12\x36\n\x0epasskeyPurpose\x18\x02 \x01(\x0e\x32\x1e.Authentication.PasskeyPurpose\x12\x15\n\rclientVersion\x18\x03 \x01(\t\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x04 \x01(\x0c\x12\x15\n\x08username\x18\x05 \x01(\tH\x00\x88\x01\x01\x12 \n\x13\x65ncryptedLoginToken\x18\x06 \x01(\x0cH\x01\x88\x01\x01\x42\x0b\n\t_usernameB\x16\n\x14_encryptedLoginToken\"\x8b\x01\n\x1dPasskeyAuthenticationResponse\x12\x18\n\x10pkRequestOptions\x18\x01 \x01(\t\x12\x16\n\x0e\x63hallengeToken\x18\x02 \x01(\x0c\x12 \n\x13\x65ncryptedLoginToken\x18\x03 \x01(\x0cH\x00\x88\x01\x01\x42\x16\n\x14_encryptedLoginToken\"\xbf\x01\n\x18PasskeyValidationRequest\x12\x16\n\x0e\x63hallengeToken\x18\x01 \x01(\x0c\x12\x19\n\x11\x61ssertionResponse\x18\x02 \x01(\x0c\x12\x36\n\x0epasskeyPurpose\x18\x03 \x01(\x0e\x32\x1e.Authentication.PasskeyPurpose\x12 \n\x13\x65ncryptedLoginToken\x18\x04 \x01(\x0cH\x00\x88\x01\x01\x42\x16\n\x14_encryptedLoginToken\"I\n\x19PasskeyValidationResponse\x12\x0f\n\x07isValid\x18\x01 \x01(\x08\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x02 \x01(\x0c\"h\n\x14UpdatePasskeyRequest\x12\x0e\n\x06userId\x18\x01 \x01(\x05\x12\x14\n\x0c\x63redentialId\x18\x02 \x01(\x0c\x12\x19\n\x0c\x66riendlyName\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_friendlyName\"-\n\x12PasskeyListRequest\x12\x17\n\x0fincludeDisabled\x18\x01 \x01(\x08\"\xa4\x01\n\x0bPasskeyInfo\x12\x0e\n\x06userId\x18\x01 \x01(\x05\x12\x14\n\x0c\x63redentialId\x18\x02 \x01(\x0c\x12\x14\n\x0c\x66riendlyName\x18\x03 \x01(\t\x12\x0e\n\x06\x41\x41GUID\x18\x04 \x01(\t\x12\x17\n\x0f\x63reatedAtMillis\x18\x05 \x01(\x03\x12\x16\n\x0elastUsedMillis\x18\x06 \x01(\x03\x12\x18\n\x10\x64isabledAtMillis\x18\x07 \x01(\x03\"G\n\x13PasskeyListResponse\x12\x30\n\x0bpasskeyInfo\x18\x01 \x03(\x0b\x32\x1b.Authentication.PasskeyInfo*\xd3\x02\n\x11SupportedLanguage\x12\x0b\n\x07\x45NGLISH\x10\x00\x12\n\n\x06\x41RABIC\x10\x01\x12\x0b\n\x07\x42RITISH\x10\x02\x12\x0b\n\x07\x43HINESE\x10\x03\x12\x15\n\x11\x43HINESE_HONG_KONG\x10\x04\x12\x12\n\x0e\x43HINESE_TAIWAN\x10\x05\x12\t\n\x05\x44UTCH\x10\x06\x12\n\n\x06\x46RENCH\x10\x07\x12\n\n\x06GERMAN\x10\x08\x12\t\n\x05GREEK\x10\t\x12\n\n\x06HEBREW\x10\n\x12\x0b\n\x07ITALIAN\x10\x0b\x12\x0c\n\x08JAPANESE\x10\x0c\x12\n\n\x06KOREAN\x10\r\x12\n\n\x06POLISH\x10\x0e\x12\x0e\n\nPORTUGUESE\x10\x0f\x12\x15\n\x11PORTUGUESE_BRAZIL\x10\x10\x12\x0c\n\x08ROMANIAN\x10\x11\x12\x0b\n\x07RUSSIAN\x10\x12\x12\n\n\x06SLOVAK\x10\x13\x12\x0b\n\x07SPANISH\x10\x14\x12\x0b\n\x07\x46INNISH\x10\x15\x12\x0b\n\x07SWEDISH\x10\x16*k\n\tLoginType\x12\n\n\x06NORMAL\x10\x00\x12\x07\n\x03SSO\x10\x01\x12\x07\n\x03\x42IO\x10\x02\x12\r\n\tALTERNATE\x10\x03\x12\x0b\n\x07OFFLINE\x10\x04\x12\x13\n\x0f\x46ORGOT_PASSWORD\x10\x05\x12\x0f\n\x0bPASSKEY_BIO\x10\x06*q\n\x0c\x44\x65viceStatus\x12\x19\n\x15\x44\x45VICE_NEEDS_APPROVAL\x10\x00\x12\r\n\tDEVICE_OK\x10\x01\x12\x1b\n\x17\x44\x45VICE_DISABLED_BY_USER\x10\x02\x12\x1a\n\x16\x44\x45VICE_LOCKED_BY_ADMIN\x10\x03*A\n\rLicenseStatus\x12\t\n\x05OTHER\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0b\n\x07\x45XPIRED\x10\x02\x12\x0c\n\x08\x44ISABLED\x10\x03*7\n\x0b\x41\x63\x63ountType\x12\x0c\n\x08\x43ONSUMER\x10\x00\x12\n\n\x06\x46\x41MILY\x10\x01\x12\x0e\n\nENTERPRISE\x10\x02*\x9f\x02\n\x10SessionTokenType\x12\x12\n\x0eNO_RESTRICTION\x10\x00\x12\x14\n\x10\x41\x43\x43OUNT_RECOVERY\x10\x01\x12\x11\n\rSHARE_ACCOUNT\x10\x02\x12\x0c\n\x08PURCHASE\x10\x03\x12\x0c\n\x08RESTRICT\x10\x04\x12\x11\n\rACCEPT_INVITE\x10\x05\x12\x12\n\x0eSUPPORT_SERVER\x10\x06\x12\x17\n\x13\x45NTERPRISE_CREATION\x10\x07\x12\x1f\n\x1b\x45XPIRED_BUT_ALLOWED_TO_SYNC\x10\x08\x12\x18\n\x14\x41\x43\x43\x45PT_FAMILY_INVITE\x10\t\x12!\n\x1d\x45NTERPRISE_CREATION_PURCHASED\x10\n\x12\x14\n\x10\x45MERGENCY_ACCESS\x10\x0b*G\n\x07Version\x12\x13\n\x0finvalid_version\x10\x00\x12\x13\n\x0f\x64\x65\x66\x61ult_version\x10\x01\x12\x12\n\x0esecond_version\x10\x02*7\n\x1fMasterPasswordReentryActionType\x12\n\n\x06UNMASK\x10\x00\x12\x08\n\x04\x43OPY\x10\x01*l\n\x0bLoginMethod\x12\x17\n\x13INVALID_LOGINMETHOD\x10\x00\x12\x14\n\x10\x45XISTING_ACCOUNT\x10\x01\x12\x0e\n\nSSO_DOMAIN\x10\x02\x12\r\n\tAFTER_SSO\x10\x03\x12\x0f\n\x0bNEW_ACCOUNT\x10\x04*\xbe\x04\n\nLoginState\x12\x16\n\x12INVALID_LOGINSTATE\x10\x00\x12\x0e\n\nLOGGED_OUT\x10\x01\x12\x1c\n\x18\x44\x45VICE_APPROVAL_REQUIRED\x10\x02\x12\x11\n\rDEVICE_LOCKED\x10\x03\x12\x12\n\x0e\x41\x43\x43OUNT_LOCKED\x10\x04\x12\x19\n\x15\x44\x45VICE_ACCOUNT_LOCKED\x10\x05\x12\x0b\n\x07UPGRADE\x10\x06\x12\x13\n\x0fLICENSE_EXPIRED\x10\x07\x12\x13\n\x0fREGION_REDIRECT\x10\x08\x12\x16\n\x12REDIRECT_CLOUD_SSO\x10\t\x12\x17\n\x13REDIRECT_ONSITE_SSO\x10\n\x12\x10\n\x0cREQUIRES_2FA\x10\x0c\x12\x16\n\x12REQUIRES_AUTH_HASH\x10\r\x12\x15\n\x11REQUIRES_USERNAME\x10\x0e\x12\x19\n\x15\x41\x46TER_CLOUD_SSO_LOGIN\x10\x0f\x12\x1d\n\x19REQUIRES_ACCOUNT_CREATION\x10\x10\x12&\n\"REQUIRES_DEVICE_ENCRYPTED_DATA_KEY\x10\x11\x12\x17\n\x13LOGIN_TOKEN_EXPIRED\x10\x12\x12\x1e\n\x1aPASSKEY_INITIATE_CHALLENGE\x10\x13\x12\x19\n\x15PASSKEY_AUTH_REQUIRED\x10\x14\x12!\n\x1dPASSKEY_VERIFY_AUTHENTICATION\x10\x15\x12\x17\n\x13\x41\x46TER_PASSKEY_LOGIN\x10\x16\x12\r\n\tLOGGED_IN\x10\x63*k\n\x14\x45ncryptedDataKeyType\x12\n\n\x06NO_KEY\x10\x00\x12\x18\n\x14\x42Y_DEVICE_PUBLIC_KEY\x10\x01\x12\x0f\n\x0b\x42Y_PASSWORD\x10\x02\x12\x10\n\x0c\x42Y_ALTERNATE\x10\x03\x12\n\n\x06\x42Y_BIO\x10\x04*-\n\x0ePasswordMethod\x12\x0b\n\x07\x45NTERED\x10\x00\x12\x0e\n\nBIOMETRICS\x10\x01*\xb9\x01\n\x11TwoFactorPushType\x12\x14\n\x10TWO_FA_PUSH_NONE\x10\x00\x12\x13\n\x0fTWO_FA_PUSH_SMS\x10\x01\x12\x16\n\x12TWO_FA_PUSH_KEEPER\x10\x02\x12\x18\n\x14TWO_FA_PUSH_DUO_PUSH\x10\x03\x12\x18\n\x14TWO_FA_PUSH_DUO_TEXT\x10\x04\x12\x18\n\x14TWO_FA_PUSH_DUO_CALL\x10\x05\x12\x13\n\x0fTWO_FA_PUSH_DNA\x10\x06*\xc3\x01\n\x12TwoFactorValueType\x12\x14\n\x10TWO_FA_CODE_NONE\x10\x00\x12\x14\n\x10TWO_FA_CODE_TOTP\x10\x01\x12\x13\n\x0fTWO_FA_CODE_SMS\x10\x02\x12\x13\n\x0fTWO_FA_CODE_DUO\x10\x03\x12\x13\n\x0fTWO_FA_CODE_RSA\x10\x04\x12\x13\n\x0fTWO_FA_RESP_U2F\x10\x05\x12\x18\n\x14TWO_FA_RESP_WEBAUTHN\x10\x06\x12\x13\n\x0fTWO_FA_CODE_DNA\x10\x07*\xe1\x01\n\x14TwoFactorChannelType\x12\x12\n\x0eTWO_FA_CT_NONE\x10\x00\x12\x12\n\x0eTWO_FA_CT_TOTP\x10\x01\x12\x11\n\rTWO_FA_CT_SMS\x10\x02\x12\x11\n\rTWO_FA_CT_DUO\x10\x03\x12\x11\n\rTWO_FA_CT_RSA\x10\x04\x12\x14\n\x10TWO_FA_CT_BACKUP\x10\x05\x12\x11\n\rTWO_FA_CT_U2F\x10\x06\x12\x16\n\x12TWO_FA_CT_WEBAUTHN\x10\x07\x12\x14\n\x10TWO_FA_CT_KEEPER\x10\x08\x12\x11\n\rTWO_FA_CT_DNA\x10\t*\xab\x01\n\x13TwoFactorExpiration\x12\x1a\n\x16TWO_FA_EXP_IMMEDIATELY\x10\x00\x12\x18\n\x14TWO_FA_EXP_5_MINUTES\x10\x01\x12\x17\n\x13TWO_FA_EXP_12_HOURS\x10\x02\x12\x17\n\x13TWO_FA_EXP_24_HOURS\x10\x03\x12\x16\n\x12TWO_FA_EXP_30_DAYS\x10\x04\x12\x14\n\x10TWO_FA_EXP_NEVER\x10\x05*@\n\x0bLicenseType\x12\t\n\x05VAULT\x10\x00\x12\x08\n\x04\x43HAT\x10\x01\x12\x0b\n\x07STORAGE\x10\x02\x12\x0f\n\x0b\x42REACHWATCH\x10\x03*i\n\x0bObjectTypes\x12\n\n\x06RECORD\x10\x00\x12\x16\n\x12SHARED_FOLDER_USER\x10\x01\x12\x16\n\x12SHARED_FOLDER_TEAM\x10\x02\x12\x0f\n\x0bUSER_FOLDER\x10\x03\x12\r\n\tTEAM_USER\x10\x04*\xa1\x02\n\x13\x45ncryptedObjectType\x12\x13\n\x0f\x45OT_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x45OT_RECORD_KEY\x10\x01\x12\x1e\n\x1a\x45OT_SHARED_FOLDER_USER_KEY\x10\x02\x12\x1e\n\x1a\x45OT_SHARED_FOLDER_TEAM_KEY\x10\x03\x12\x15\n\x11\x45OT_TEAM_USER_KEY\x10\x04\x12\x17\n\x13\x45OT_USER_FOLDER_KEY\x10\x05\x12\x15\n\x11\x45OT_SECURITY_DATA\x10\x06\x12%\n!EOT_SECURITY_DATA_MASTER_PASSWORD\x10\x07\x12\x1c\n\x18\x45OT_EMERGENCY_ACCESS_KEY\x10\x08\x12\x15\n\x11\x45OT_V2_RECORD_KEY\x10\t*M\n\x1bMasterPasswordReentryStatus\x12\x0e\n\nMP_UNKNOWN\x10\x00\x12\x0e\n\nMP_SUCCESS\x10\x01\x12\x0e\n\nMP_FAILURE\x10\x02*`\n\x1b\x41lternateAuthenticationType\x12\x1d\n\x19\x41LTERNATE_MASTER_PASSWORD\x10\x00\x12\r\n\tBIOMETRIC\x10\x01\x12\x13\n\x0f\x41\x43\x43OUNT_RECOVER\x10\x02*\x9a\x02\n\x0cThrottleType\x12\x1b\n\x17PASSWORD_RETRY_THROTTLE\x10\x00\x12\"\n\x1ePASSWORD_RETRY_LEGACY_THROTTLE\x10\x01\x12\x13\n\x0fTWO_FA_THROTTLE\x10\x02\x12\x1a\n\x16TWO_FA_LEGACY_THROTTLE\x10\x03\x12\x15\n\x11QA_RETRY_THROTTLE\x10\x04\x12\x1c\n\x18\x41\x43\x43OUNT_RECOVER_THROTTLE\x10\x05\x12.\n*VALIDATE_DEVICE_VERIFICATION_CODE_THROTTLE\x10\x06\x12\x33\n/VALIDATE_CREATE_USER_VERIFICATION_CODE_THROTTLE\x10\x07*H\n\x06Region\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x06\n\x02\x65u\x10\x01\x12\x06\n\x02us\x10\x02\x12\t\n\x05usgov\x10\x03\x12\x06\n\x02\x61u\x10\x04\x12\x06\n\x02jp\x10\x05\x12\x06\n\x02\x63\x61\x10\x06*D\n\x14\x41pplicationShareType\x12\x15\n\x11SHARE_TYPE_RECORD\x10\x00\x12\x15\n\x11SHARE_TYPE_FOLDER\x10\x01*\xa4\x01\n\x15TimeLimitedAccessType\x12$\n INVALID_TIME_LIMITED_ACCESS_TYPE\x10\x00\x12\x19\n\x15USER_ACCESS_TO_RECORD\x10\x01\x12\'\n#USER_OR_TEAM_ACCESS_TO_SHAREDFOLDER\x10\x02\x12!\n\x1dRECORD_ACCESS_TO_SHAREDFOLDER\x10\x03*<\n\rBackupKeyType\x12\x12\n\x0e\x42KT_SEC_ANSWER\x10\x00\x12\x17\n\x13\x42KT_PASSPHRASE_HASH\x10\x01*W\n\rGenericStatus\x12\x0b\n\x07SUCCESS\x10\x00\x12\x12\n\x0eINVALID_OBJECT\x10\x01\x12\x12\n\x0e\x41LREADY_EXISTS\x10\x02\x12\x11\n\rACCESS_DENIED\x10\x03*N\n\x17\x41uthenticatorAttachment\x12\x12\n\x0e\x43ROSS_PLATFORM\x10\x00\x12\x0c\n\x08PLATFORM\x10\x01\x12\x11\n\rALL_SUPPORTED\x10\x02*-\n\x0ePasskeyPurpose\x12\x0c\n\x08PK_LOGIN\x10\x00\x12\r\n\tPK_REAUTH\x10\x01*K\n\x10\x43lientFormFactor\x12\x0c\n\x08\x46\x46_EMPTY\x10\x00\x12\x0c\n\x08\x46\x46_PHONE\x10\x01\x12\r\n\tFF_TABLET\x10\x02\x12\x0c\n\x08\x46\x46_WATCH\x10\x03\x42*\n\x18\x63om.keepersecurity.protoB\x0e\x41uthenticationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'APIRequest_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030com.keepersecurity.protoB\016Authentication'
  _globals['_SUPPORTEDLANGUAGE']._serialized_start=20538
  _globals['_SUPPORTEDLANGUAGE']._serialized_end=20877
  _globals['_LOGINTYPE']._serialized_start=20879
  _globals['_LOGINTYPE']._serialized_end=20986
  _globals['_DEVICESTATUS']._serialized_start=20988
  _globals['_DEVICESTATUS']._serialized_end=21101
  _globals['_LICENSESTATUS']._serialized_start=21103
  _globals['_LICENSESTATUS']._serialized_end=21168
  _globals['_ACCOUNTTYPE']._serialized_start=21170
  _globals['_ACCOUNTTYPE']._serialized_end=21225
  _globals['_SESSIONTOKENTYPE']._serialized_start=21228
  _globals['_SESSIONTOKENTYPE']._serialized_end=21515
  _globals['_VERSION']._serialized_start=21517
  _globals['_VERSION']._serialized_end=21588
  _globals['_MASTERPASSWORDREENTRYACTIONTYPE']._serialized_start=21590
  _globals['_MASTERPASSWORDREENTRYACTIONTYPE']._serialized_end=21645
  _globals['_LOGINMETHOD']._serialized_start=21647
  _globals['_LOGINMETHOD']._serialized_end=21755
  _globals['_LOGINSTATE']._serialized_start=21758
  _globals['_LOGINSTATE']._serialized_end=22332
  _globals['_ENCRYPTEDDATAKEYTYPE']._serialized_start=22334
  _globals['_ENCRYPTEDDATAKEYTYPE']._serialized_end=22441
  _globals['_PASSWORDMETHOD']._serialized_start=22443
  _globals['_PASSWORDMETHOD']._serialized_end=22488
  _globals['_TWOFACTORPUSHTYPE']._serialized_start=22491
  _globals['_TWOFACTORPUSHTYPE']._serialized_end=22676
  _globals['_TWOFACTORVALUETYPE']._serialized_start=22679
  _globals['_TWOFACTORVALUETYPE']._serialized_end=22874
  _globals['_TWOFACTORCHANNELTYPE']._serialized_start=22877
  _globals['_TWOFACTORCHANNELTYPE']._serialized_end=23102
  _globals['_TWOFACTOREXPIRATION']._serialized_start=23105
  _globals['_TWOFACTOREXPIRATION']._serialized_end=23276
  _globals['_LICENSETYPE']._serialized_start=23278
  _globals['_LICENSETYPE']._serialized_end=23342
  _globals['_OBJECTTYPES']._serialized_start=23344
  _globals['_OBJECTTYPES']._serialized_end=23449
  _globals['_ENCRYPTEDOBJECTTYPE']._serialized_start=23452
  _globals['_ENCRYPTEDOBJECTTYPE']._serialized_end=23741
  _globals['_MASTERPASSWORDREENTRYSTATUS']._serialized_start=23743
  _globals['_MASTERPASSWORDREENTRYSTATUS']._serialized_end=23820
  _globals['_ALTERNATEAUTHENTICATIONTYPE']._serialized_start=23822
  _globals['_ALTERNATEAUTHENTICATIONTYPE']._serialized_end=23918
  _globals['_THROTTLETYPE']._serialized_start=23921
  _globals['_THROTTLETYPE']._serialized_end=24203
  _globals['_REGION']._serialized_start=24205
  _globals['_REGION']._serialized_end=24277
  _globals['_APPLICATIONSHARETYPE']._serialized_start=24279
  _globals['_APPLICATIONSHARETYPE']._serialized_end=24347
  _globals['_TIMELIMITEDACCESSTYPE']._serialized_start=24350
  _globals['_TIMELIMITEDACCESSTYPE']._serialized_end=24514
  _globals['_BACKUPKEYTYPE']._serialized_start=24516
  _globals['_BACKUPKEYTYPE']._serialized_end=24576
  _globals['_GENERICSTATUS']._serialized_start=24578
  _globals['_GENERICSTATUS']._serialized_end=24665
  _globals['_AUTHENTICATORATTACHMENT']._serialized_start=24667
  _globals['_AUTHENTICATORATTACHMENT']._serialized_end=24745
  _globals['_PASSKEYPURPOSE']._serialized_start=24747
  _globals['_PASSKEYPURPOSE']._serialized_end=24792
  _globals['_CLIENTFORMFACTOR']._serialized_start=24794
  _globals['_CLIENTFORMFACTOR']._serialized_end=24869
  _globals['_APIREQUEST']._serialized_start=55
  _globals['_APIREQUEST']._serialized_end=231
  _globals['_APIREQUESTPAYLOAD']._serialized_start=233
  _globals['_APIREQUESTPAYLOAD']._serialized_end=339
  _globals['_TRANSFORM']._serialized_start=341
  _globals['_TRANSFORM']._serialized_end=395
  _globals['_DEVICEREQUEST']._serialized_start=398
  _globals['_DEVICEREQUEST']._serialized_end=540
  _globals['_AUTHREQUEST']._serialized_start=542
  _globals['_AUTHREQUEST']._serialized_end=626
  _globals['_NEWUSERMINIMUMPARAMS']._serialized_start=629
  _globals['_NEWUSERMINIMUMPARAMS']._serialized_end=824
  _globals['_PRELOGINREQUEST']._serialized_start=827
  _globals['_PRELOGINREQUEST']._serialized_end=964
  _globals['_LOGINREQUEST']._serialized_start=967
  _globals['_LOGINREQUEST']._serialized_end=1223
  _globals['_DEVICERESPONSE']._serialized_start=1225
  _globals['_DEVICERESPONSE']._serialized_end=1317
  _globals['_SALT']._serialized_start=1319
  _globals['_SALT']._serialized_end=1405
  _globals['_TWOFACTORCHANNEL']._serialized_start=1407
  _globals['_TWOFACTORCHANNEL']._serialized_end=1439
  _globals['_STARTLOGINREQUEST']._serialized_start=1442
  _globals['_STARTLOGINREQUEST']._serialized_end=1822
  _globals['_LOGINRESPONSE']._serialized_start=1825
  _globals['_LOGINRESPONSE']._serialized_end=2376
  _globals['_SWITCHLISTELEMENT']._serialized_start=2378
  _globals['_SWITCHLISTELEMENT']._serialized_end=2473
  _globals['_SWITCHLISTRESPONSE']._serialized_start=2475
  _globals['_SWITCHLISTRESPONSE']._serialized_end=2548
  _globals['_SSOUSERINFO']._serialized_start=2551
  _globals['_SSOUSERINFO']._serialized_end=2691
  _globals['_PRELOGINRESPONSE']._serialized_start=2694
  _globals['_PRELOGINRESPONSE']._serialized_end=2908
  _globals['_LOGINASUSERREQUEST']._serialized_start=2910
  _globals['_LOGINASUSERREQUEST']._serialized_end=2948
  _globals['_LOGINASUSERRESPONSE']._serialized_start=2950
  _globals['_LOGINASUSERRESPONSE']._serialized_end=3037
  _globals['_VALIDATEAUTHHASHREQUEST']._serialized_start=3040
  _globals['_VALIDATEAUTHHASHREQUEST']._serialized_end=3172
  _globals['_TWOFACTORCHANNELINFO']._serialized_start=3175
  _globals['_TWOFACTORCHANNELINFO']._serialized_end=3499
  _globals['_TWOFACTORDUOSTATUS']._serialized_start=3501
  _globals['_TWOFACTORDUOSTATUS']._serialized_end=3601
  _globals['_TWOFACTORADDREQUEST']._serialized_start=3604
  _globals['_TWOFACTORADDREQUEST']._serialized_end=3803
  _globals['_TWOFACTORRENAMEREQUEST']._serialized_start=3805
  _globals['_TWOFACTORRENAMEREQUEST']._serialized_end=3871
  _globals['_TWOFACTORADDRESPONSE']._serialized_start=3873
  _globals['_TWOFACTORADDRESPONSE']._serialized_end=3934
  _globals['_TWOFACTORDELETEREQUEST']._serialized_start=3936
  _globals['_TWOFACTORDELETEREQUEST']._serialized_end=3981
  _globals['_TWOFACTORLISTRESPONSE']._serialized_start=3983
  _globals['_TWOFACTORLISTRESPONSE']._serialized_end=4080
  _globals['_TWOFACTORUPDATEEXPIRATIONREQUEST']._serialized_start=4082
  _globals['_TWOFACTORUPDATEEXPIRATIONREQUEST']._serialized_end=4171
  _globals['_TWOFACTORVALIDATEREQUEST']._serialized_start=4174
  _globals['_TWOFACTORVALIDATEREQUEST']._serialized_end=4375
  _globals['_TWOFACTORVALIDATERESPONSE']._serialized_start=4377
  _globals['_TWOFACTORVALIDATERESPONSE']._serialized_end=4433
  _globals['_TWOFACTORSENDPUSHREQUEST']._serialized_start=4436
  _globals['_TWOFACTORSENDPUSHREQUEST']._serialized_end=4620
  _globals['_LICENSE']._serialized_start=4623
  _globals['_LICENSE']._serialized_end=4754
  _globals['_OWNERLESSRECORD']._serialized_start=4756
  _globals['_OWNERLESSRECORD']._serialized_end=4827
  _globals['_OWNERLESSRECORDS']._serialized_start=4829
  _globals['_OWNERLESSRECORDS']._serialized_end=4905
  _globals['_USERAUTHREQUEST']._serialized_start=4908
  _globals['_USERAUTHREQUEST']._serialized_end=5123
  _globals['_UIDREQUEST']._serialized_start=5125
  _globals['_UIDREQUEST']._serialized_end=5150
  _globals['_DEVICEUPDATEREQUEST']._serialized_start=5153
  _globals['_DEVICEUPDATEREQUEST']._serialized_end=5408
  _globals['_REGISTERDEVICEINREGIONREQUEST']._serialized_start=5411
  _globals['_REGISTERDEVICEINREGIONREQUEST']._serialized_end=5624
  _globals['_REGISTRATIONREQUEST']._serialized_start=5627
  _globals['_REGISTRATIONREQUEST']._serialized_end=6003
  _globals['_CONVERTUSERTOV3REQUEST']._serialized_start=6006
  _globals['_CONVERTUSERTOV3REQUEST']._serialized_end=6214
  _globals['_REVISIONRESPONSE']._serialized_start=6216
  _globals['_REVISIONRESPONSE']._serialized_end=6252
  _globals['_CHANGEEMAILREQUEST']._serialized_start=6254
  _globals['_CHANGEEMAILREQUEST']._serialized_end=6292
  _globals['_CHANGEEMAILRESPONSE']._serialized_start=6294
  _globals['_CHANGEEMAILRESPONSE']._serialized_end=6350
  _globals['_EMAILVERIFICATIONLINKRESPONSE']._serialized_start=6352
  _globals['_EMAILVERIFICATIONLINKRESPONSE']._serialized_end=6406
  _globals['_SECURITYDATA']._serialized_start=6408
  _globals['_SECURITYDATA']._serialized_end=6449
  _globals['_SECURITYSCOREDATA']._serialized_start=6451
  _globals['_SECURITYSCOREDATA']._serialized_end=6515
  _globals['_SECURITYDATAREQUEST']._serialized_start=6518
  _globals['_SECURITYDATAREQUEST']._serialized_end=6785
  _globals['_SECURITYREPORTINCREMENTALDATA']._serialized_start=6788
  _globals['_SECURITYREPORTINCREMENTALDATA']._serialized_end=7095
  _globals['_SECURITYREPORT']._serialized_start=7098
  _globals['_SECURITYREPORT']._serialized_end=7385
  _globals['_SECURITYREPORTSAVEREQUEST']._serialized_start=7387
  _globals['_SECURITYREPORTSAVEREQUEST']._serialized_end=7470
  _globals['_SECURITYREPORTREQUEST']._serialized_start=7472
  _globals['_SECURITYREPORTREQUEST']._serialized_end=7513
  _globals['_SECURITYREPORTRESPONSE']._serialized_start=7516
  _globals['_SECURITYREPORTRESPONSE']._serialized_end=7733
  _globals['_REUSEDPASSWORDSREQUEST']._serialized_start=7735
  _globals['_REUSEDPASSWORDSREQUEST']._serialized_end=7774
  _globals['_SUMMARYCONSOLEREPORT']._serialized_start=7776
  _globals['_SUMMARYCONSOLEREPORT']._serialized_end=7838
  _globals['_CHANGETOKEYTYPEONE']._serialized_start=7840
  _globals['_CHANGETOKEYTYPEONE']._serialized_end=7964
  _globals['_CHANGETOKEYTYPEONEREQUEST']._serialized_start=7966
  _globals['_CHANGETOKEYTYPEONEREQUEST']._serialized_end=8057
  _globals['_CHANGETOKEYTYPEONESTATUS']._serialized_start=8059
  _globals['_CHANGETOKEYTYPEONESTATUS']._serialized_end=8144
  _globals['_CHANGETOKEYTYPEONERESPONSE']._serialized_start=8146
  _globals['_CHANGETOKEYTYPEONERESPONSE']._serialized_end=8250
  _globals['_GETCHANGEKEYTYPESREQUEST']._serialized_start=8253
  _globals['_GETCHANGEKEYTYPESREQUEST']._serialized_end=8438
  _globals['_GETCHANGEKEYTYPESRESPONSE']._serialized_start=8441
  _globals['_GETCHANGEKEYTYPESRESPONSE']._serialized_end=8571
  _globals['_ALLOWEDKEYTYPES']._serialized_start=8574
  _globals['_ALLOWEDKEYTYPES']._serialized_end=8703
  _globals['_CHANGEKEYTYPES']._serialized_start=8705
  _globals['_CHANGEKEYTYPES']._serialized_end=8766
  _globals['_CHANGEKEYTYPE']._serialized_start=8769
  _globals['_CHANGEKEYTYPE']._serialized_end=8983
  _globals['_SETKEY']._serialized_start=8985
  _globals['_SETKEY']._serialized_end=9018
  _globals['_SETKEYREQUEST']._serialized_start=9020
  _globals['_SETKEYREQUEST']._serialized_end=9073
  _globals['_CREATEUSERREQUEST']._serialized_start=9076
  _globals['_CREATEUSERREQUEST']._serialized_end=9734
  _globals['_NODEENFORCEMENTADDORUPDATEREQUEST']._serialized_start=9736
  _globals['_NODEENFORCEMENTADDORUPDATEREQUEST']._serialized_end=9823
  _globals['_NODEENFORCEMENTREMOVEREQUEST']._serialized_start=9825
  _globals['_NODEENFORCEMENTREMOVEREQUEST']._serialized_end=9892
  _globals['_APIREQUESTBYKEY']._serialized_start=9895
  _globals['_APIREQUESTBYKEY']._serialized_end=10054
  _globals['_APIREQUESTBYKATOKAKEY']._serialized_start=10057
  _globals['_APIREQUESTBYKATOKAKEY']._serialized_end=10256
  _globals['_MEMCACHEREQUEST']._serialized_start=10258
  _globals['_MEMCACHEREQUEST']._serialized_end=10304
  _globals['_MEMCACHERESPONSE']._serialized_start=10306
  _globals['_MEMCACHERESPONSE']._serialized_end=10352
  _globals['_MASTERPASSWORDREENTRYREQUEST']._serialized_start=10354
  _globals['_MASTERPASSWORDREENTRYREQUEST']._serialized_end=10473
  _globals['_MASTERPASSWORDREENTRYRESPONSE']._serialized_start=10475
  _globals['_MASTERPASSWORDREENTRYRESPONSE']._serialized_end=10567
  _globals['_DEVICEREGISTRATIONREQUEST']._serialized_start=10570
  _globals['_DEVICEREGISTRATIONREQUEST']._serialized_end=10749
  _globals['_DEVICEVERIFICATIONREQUEST']._serialized_start=10752
  _globals['_DEVICEVERIFICATIONREQUEST']._serialized_end=10906
  _globals['_DEVICEVERIFICATIONRESPONSE']._serialized_start=10909
  _globals['_DEVICEVERIFICATIONRESPONSE']._serialized_end=11087
  _globals['_DEVICEAPPROVALREQUEST']._serialized_start=11090
  _globals['_DEVICEAPPROVALREQUEST']._serialized_end=11290
  _globals['_DEVICEAPPROVALRESPONSE']._serialized_start=11292
  _globals['_DEVICEAPPROVALRESPONSE']._serialized_end=11349
  _globals['_APPROVEDEVICEREQUEST']._serialized_start=11351
  _globals['_APPROVEDEVICEREQUEST']._serialized_end=11477
  _globals['_ENTERPRISEUSERALIASREQUEST']._serialized_start=11479
  _globals['_ENTERPRISEUSERALIASREQUEST']._serialized_end=11548
  _globals['_ENTERPRISEUSERADDALIASREQUEST']._serialized_start=11550
  _globals['_ENTERPRISEUSERADDALIASREQUEST']._serialized_end=11639
  _globals['_ENTERPRISEUSERADDALIASREQUESTV2']._serialized_start=11641
  _globals['_ENTERPRISEUSERADDALIASREQUESTV2']._serialized_end=11760
  _globals['_ENTERPRISEUSERADDALIASSTATUS']._serialized_start=11762
  _globals['_ENTERPRISEUSERADDALIASSTATUS']._serialized_end=11834
  _globals['_ENTERPRISEUSERADDALIASRESPONSE']._serialized_start=11836
  _globals['_ENTERPRISEUSERADDALIASRESPONSE']._serialized_end=11930
  _globals['_DEVICE']._serialized_start=11932
  _globals['_DEVICE']._serialized_end=11970
  _globals['_REGISTERDEVICEDATAKEYREQUEST']._serialized_start=11972
  _globals['_REGISTERDEVICEDATAKEYREQUEST']._serialized_end=12064
  _globals['_VALIDATECREATEUSERVERIFICATIONCODEREQUEST']._serialized_start=12066
  _globals['_VALIDATECREATEUSERVERIFICATIONCODEREQUEST']._serialized_end=12176
  _globals['_VALIDATEDEVICEVERIFICATIONCODEREQUEST']._serialized_start=12179
  _globals['_VALIDATEDEVICEVERIFICATIONCODEREQUEST']._serialized_end=12342
  _globals['_SENDSESSIONMESSAGEREQUEST']._serialized_start=12344
  _globals['_SENDSESSIONMESSAGEREQUEST']._serialized_end=12433
  _globals['_GLOBALUSERACCOUNT']._serialized_start=12435
  _globals['_GLOBALUSERACCOUNT']._serialized_end=12512
  _globals['_ACCOUNTUSERNAME']._serialized_start=12514
  _globals['_ACCOUNTUSERNAME']._serialized_end=12569
  _globals['_SSOSERVICEPROVIDERREQUEST']._serialized_start=12571
  _globals['_SSOSERVICEPROVIDERREQUEST']._serialized_end=12651
  _globals['_SSOSERVICEPROVIDERRESPONSE']._serialized_start=12653
  _globals['_SSOSERVICEPROVIDERRESPONSE']._serialized_end=12750
  _globals['_USERSETTINGREQUEST']._serialized_start=12752
  _globals['_USERSETTINGREQUEST']._serialized_end=12804
  _globals['_THROTTLESTATE']._serialized_start=12806
  _globals['_THROTTLESTATE']._serialized_end=12908
  _globals['_THROTTLESTATE2']._serialized_start=12911
  _globals['_THROTTLESTATE2']._serialized_end=13092
  _globals['_DEVICEINFORMATION']._serialized_start=13095
  _globals['_DEVICEINFORMATION']._serialized_end=13246
  _globals['_USERSETTING']._serialized_start=13248
  _globals['_USERSETTING']._serialized_end=13290
  _globals['_USERDATAKEYREQUEST']._serialized_start=13292
  _globals['_USERDATAKEYREQUEST']._serialized_end=13338
  _globals['_USERDATAKEYBYNODEREQUEST']._serialized_start=13340
  _globals['_USERDATAKEYBYNODEREQUEST']._serialized_end=13383
  _globals['_ENTERPRISEUSERIDDATAKEYPAIR']._serialized_start=13386
  _globals['_ENTERPRISEUSERIDDATAKEYPAIR']._serialized_end=13514
  _globals['_USERDATAKEY']._serialized_start=13517
  _globals['_USERDATAKEY']._serialized_end=13666
  _globals['_USERDATAKEYRESPONSE']._serialized_start=13668
  _globals['_USERDATAKEYRESPONSE']._serialized_end=13790
  _globals['_MASTERPASSWORDRECOVERYVERIFICATIONREQUEST']._serialized_start=13792
  _globals['_MASTERPASSWORDRECOVERYVERIFICATIONREQUEST']._serialized_end=13864
  _globals['_GETSECURITYQUESTIONV3REQUEST']._serialized_start=13866
  _globals['_GETSECURITYQUESTIONV3REQUEST']._serialized_end=13951
  _globals['_GETSECURITYQUESTIONV3RESPONSE']._serialized_start=13953
  _globals['_GETSECURITYQUESTIONV3RESPONSE']._serialized_end=14067
  _globals['_GETDATAKEYBACKUPV3REQUEST']._serialized_start=14069
  _globals['_GETDATAKEYBACKUPV3REQUEST']._serialized_end=14179
  _globals['_PASSWORDRULES']._serialized_start=14181
  _globals['_PASSWORDRULES']._serialized_end=14299
  _globals['_GETDATAKEYBACKUPV3RESPONSE']._serialized_start=14302
  _globals['_GETDATAKEYBACKUPV3RESPONSE']._serialized_end=14631
  _globals['_GETPUBLICKEYSREQUEST']._serialized_start=14633
  _globals['_GETPUBLICKEYSREQUEST']._serialized_end=14674
  _globals['_PUBLICKEYRESPONSE']._serialized_start=14676
  _globals['_PUBLICKEYRESPONSE']._serialized_end=14790
  _globals['_GETPUBLICKEYSRESPONSE']._serialized_start=14792
  _globals['_GETPUBLICKEYSRESPONSE']._serialized_end=14872
  _globals['_SETECCKEYPAIRREQUEST']._serialized_start=14874
  _globals['_SETECCKEYPAIRREQUEST']._serialized_end=14944
  _globals['_SETECCKEYPAIRSREQUEST']._serialized_start=14946
  _globals['_SETECCKEYPAIRSREQUEST']._serialized_end=15019
  _globals['_SETECCKEYPAIRSRESPONSE']._serialized_start=15021
  _globals['_SETECCKEYPAIRSRESPONSE']._serialized_end=15103
  _globals['_TEAMECCKEYPAIR']._serialized_start=15105
  _globals['_TEAMECCKEYPAIR']._serialized_end=15186
  _globals['_TEAMECCKEYPAIRRESPONSE']._serialized_start=15188
  _globals['_TEAMECCKEYPAIRRESPONSE']._serialized_end=15276
  _globals['_GETKSMPUBLICKEYSREQUEST']._serialized_start=15278
  _globals['_GETKSMPUBLICKEYSREQUEST']._serialized_end=15346
  _globals['_DEVICEPUBLICKEYRESPONSE']._serialized_start=15348
  _globals['_DEVICEPUBLICKEYRESPONSE']._serialized_end=15433
  _globals['_GETKSMPUBLICKEYSRESPONSE']._serialized_start=15435
  _globals['_GETKSMPUBLICKEYSRESPONSE']._serialized_end=15524
  _globals['_ADDAPPSHARESREQUEST']._serialized_start=15526
  _globals['_ADDAPPSHARESREQUEST']._serialized_end=15614
  _globals['_REMOVEAPPSHARESREQUEST']._serialized_start=15616
  _globals['_REMOVEAPPSHARESREQUEST']._serialized_end=15678
  _globals['_APPSHAREADD']._serialized_start=15681
  _globals['_APPSHAREADD']._serialized_end=15816
  _globals['_APPSHARE']._serialized_start=15819
  _globals['_APPSHARE']._serialized_end=15956
  _globals['_ADDAPPCLIENTREQUEST']._serialized_start=15959
  _globals['_ADDAPPCLIENTREQUEST']._serialized_end=16176
  _globals['_REMOVEAPPCLIENTSREQUEST']._serialized_start=16178
  _globals['_REMOVEAPPCLIENTSREQUEST']._serialized_end=16242
  _globals['_ADDEXTERNALSHAREREQUEST']._serialized_start=16245
  _globals['_ADDEXTERNALSHAREREQUEST']._serialized_end=16415
  _globals['_APPCLIENT']._serialized_start=16418
  _globals['_APPCLIENT']._serialized_end=16693
  _globals['_GETAPPINFOREQUEST']._serialized_start=16695
  _globals['_GETAPPINFOREQUEST']._serialized_end=16736
  _globals['_APPINFO']._serialized_start=16739
  _globals['_APPINFO']._serialized_end=16881
  _globals['_GETAPPINFORESPONSE']._serialized_start=16883
  _globals['_GETAPPINFORESPONSE']._serialized_end=16945
  _globals['_APPLICATIONSUMMARY']._serialized_start=16948
  _globals['_APPLICATIONSUMMARY']._serialized_end=17161
  _globals['_GETAPPLICATIONSSUMMARYRESPONSE']._serialized_start=17163
  _globals['_GETAPPLICATIONSSUMMARYRESPONSE']._serialized_end=17259
  _globals['_GETVERIFICATIONTOKENREQUEST']._serialized_start=17261
  _globals['_GETVERIFICATIONTOKENREQUEST']._serialized_end=17308
  _globals['_GETVERIFICATIONTOKENRESPONSE']._serialized_start=17310
  _globals['_GETVERIFICATIONTOKENRESPONSE']._serialized_end=17376
  _globals['_SENDSHAREINVITEREQUEST']._serialized_start=17378
  _globals['_SENDSHAREINVITEREQUEST']._serialized_end=17417
  _globals['_TIMELIMITEDACCESSREQUEST']._serialized_start=17420
  _globals['_TIMELIMITEDACCESSREQUEST']._serialized_end=17617
  _globals['_TIMELIMITEDACCESSSTATUS']._serialized_start=17619
  _globals['_TIMELIMITEDACCESSSTATUS']._serialized_end=17674
  _globals['_TIMELIMITEDACCESSRESPONSE']._serialized_start=17677
  _globals['_TIMELIMITEDACCESSRESPONSE']._serialized_end=17925
  _globals['_REQUESTDOWNLOADREQUEST']._serialized_start=17927
  _globals['_REQUESTDOWNLOADREQUEST']._serialized_end=17970
  _globals['_REQUESTDOWNLOADRESPONSE']._serialized_start=17972
  _globals['_REQUESTDOWNLOADRESPONSE']._serialized_end=18075
  _globals['_DOWNLOAD']._serialized_start=18077
  _globals['_DOWNLOAD']._serialized_end=18145
  _globals['_DELETEUSERREQUEST']._serialized_start=18147
  _globals['_DELETEUSERREQUEST']._serialized_end=18182
  _globals['_CHANGEMASTERPASSWORDREQUEST']._serialized_start=18185
  _globals['_CHANGEMASTERPASSWORDREQUEST']._serialized_end=18317
  _globals['_CHANGEMASTERPASSWORDRESPONSE']._serialized_start=18319
  _globals['_CHANGEMASTERPASSWORDRESPONSE']._serialized_end=18380
  _globals['_ACCOUNTRECOVERYSETUPREQUEST']._serialized_start=18382
  _globals['_ACCOUNTRECOVERYSETUPREQUEST']._serialized_end=18471
  _globals['_ACCOUNTRECOVERYVERIFYCODERESPONSE']._serialized_start=18474
  _globals['_ACCOUNTRECOVERYVERIFYCODERESPONSE']._serialized_end=18646
  _globals['_EMERGENCYACCESSLOGINREQUEST']._serialized_start=18648
  _globals['_EMERGENCYACCESSLOGINREQUEST']._serialized_end=18692
  _globals['_EMERGENCYACCESSLOGINRESPONSE']._serialized_start=18695
  _globals['_EMERGENCYACCESSLOGINRESPONSE']._serialized_end=18876
  _globals['_USERTEAMKEY']._serialized_start=18879
  _globals['_USERTEAMKEY']._serialized_end=19057
  _globals['_GENERICREQUESTRESPONSE']._serialized_start=19059
  _globals['_GENERICREQUESTRESPONSE']._serialized_end=19100
  _globals['_PASSKEYREGISTRATIONREQUEST']._serialized_start=19102
  _globals['_PASSKEYREGISTRATIONREQUEST']._serialized_end=19204
  _globals['_PASSKEYREGISTRATIONRESPONSE']._serialized_start=19206
  _globals['_PASSKEYREGISTRATIONRESPONSE']._serialized_end=19286
  _globals['_PASSKEYREGISTRATIONFINALIZATION']._serialized_start=19289
  _globals['_PASSKEYREGISTRATIONFINALIZATION']._serialized_end=19421
  _globals['_PASSKEYAUTHENTICATIONREQUEST']._serialized_start=19424
  _globals['_PASSKEYAUTHENTICATIONREQUEST']._serialized_end=19731
  _globals['_PASSKEYAUTHENTICATIONRESPONSE']._serialized_start=19734
  _globals['_PASSKEYAUTHENTICATIONRESPONSE']._serialized_end=19873
  _globals['_PASSKEYVALIDATIONREQUEST']._serialized_start=19876
  _globals['_PASSKEYVALIDATIONREQUEST']._serialized_end=20067
  _globals['_PASSKEYVALIDATIONRESPONSE']._serialized_start=20069
  _globals['_PASSKEYVALIDATIONRESPONSE']._serialized_end=20142
  _globals['_UPDATEPASSKEYREQUEST']._serialized_start=20144
  _globals['_UPDATEPASSKEYREQUEST']._serialized_end=20248
  _globals['_PASSKEYLISTREQUEST']._serialized_start=20250
  _globals['_PASSKEYLISTREQUEST']._serialized_end=20295
  _globals['_PASSKEYINFO']._serialized_start=20298
  _globals['_PASSKEYINFO']._serialized_end=20462
  _globals['_PASSKEYLISTRESPONSE']._serialized_start=20464
  _globals['_PASSKEYLISTRESPONSE']._serialized_end=20535
# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python3
"""
Generates JSON file ready to be imported by pam project import command.
This example generates JSON that creates one AD machine (pamDirectory)
with AD Admin user (pamUser) and multiple local machines (pamMachine)
configured with connections and rotation enabled and AD Admin as their admin.

This script uses external CSV file (format: server_name,user_name,password)
and external JSON template with static pamDirectory and its pamUser and
a dynamic placeholder used for each pamMachine and its pamUser (from CSV)

You can use any of the full set of options per user/machine type from our docs
https://github.com/Keeper-Security/Commander/blob/master/keepercommander/commands/pam_import/README.md
You can also run the script with --show-template option and use it as startnig point.

Command line options:
    -i, --input-file    default = servers_to_import.csv
                        Specify the input file CSV: hostname,user,password
    -o, --output-file   default = pam_import.json
                        Specify the JSON output file
    -t, --template-file default = import_template.json
                        Specify the JSON template file
    -s, --show-template Show sample JSON template (overrides all options)
    -p, --prefix-names  Enable username prefixes (server1-admin vs admin)
"""
from __future__ import annotations

import argparse
import copy
import csv
import json
import os
import sys
from pathlib import Path
from typing import Any, Dict, List


DEFAULT_IMPORT_TEMPLATE = """{
    "project": "Project1",
    "shared_folder_users": { "manage_users": true, "manage_records": true, "can_edit": true, "can_share": true },
    "shared_folder_resources": { "manage_users": true, "manage_records": true, "can_edit": true, "can_share": true },
    "pam_configuration": { "environment": "local", "connections": "on", "rotation": "on", "graphical_session_recording": "on" },
    "pam_data": {
        "resources": [
            {
                "_comment1": "Every key that starts with '_' is a comment and can be ignored or deleted",
                "_comment2": "Every value that starts with uppercase 'XXX:' must be replaced with actual value (removed if not required)",
                "_comment3": "Every value that starts with lowercase 'xxx:' is just a placeholder - can be replaced with anything but must be present",
                "type": "pamDirectory",
                "title": "XXX:Project1 AD",
                "directory_type": "XXX:active_directory|ldap",
                "host": "XXX:demo.local",
                "port": "XXX:636",
                "use_ssl": true,
                "domain_name": "XXX:demo.local",
                "pam_settings": {
                    "options" : { "rotation": "on", "connections": "on", "tunneling": "on", "graphical_session_recording": "on" },
                    "connection" : {
                        "protocol": "rdp",
                        "port": "XXX:3389",
                        "security": "XXX:any",
                        "ignore_server_cert": true,
                        "_comment_administrative_credentials": "Must match the unique title of one of the users below",
                        "administrative_credentials": "XXX:DomainAdmin"
                    }
                },
                "users": [{
                    "type": "pamUser",
                    "_comment_title": "Must match administrative_credentials above if this is the admin user",
                    "title": "XXX:DomainAdmin",
                    "_comment_login_password": "Must provide valid credentials but delete sensitive data/json after import",
                    "login": "XXX:administrator@demo.local",
                    "password": "XXX:P4ssw0rd_123",
                    "rotation_settings": { "rotation": "general", "enabled": "on", "schedule": {"type": "on-demand"}}
                }]
            },
            {
                "_comment4": "While pamDirectory section above is static, the pamMachine section below is dynamically generated",
                "_comment5": "One pamMachine with one pamUser will be generated per each line from the CSV file",
                "_comment6": "Only one pamMachine is needed and it will be used as a template for all CSV rows",
                "_comment7": "Please do NOT edit lines with xxx: in them - these are placeholders",
                "_comment8": "Any other line that don't contain xxx: can be altered/added/deleted in the template",
                "_comment9": "CSV Format: server_name,username,password",
                "type": "pamMachine",
                "_comment_title_and_host": "server value from CSV",
                "title": "xxx:server1",
                "host": "xxx:server1",
                "port": "5986",
                "ssl_verification" : true,
                "operating_system": "Windows",
                "pam_settings": {
                    "options" : { "rotation": "on", "connections": "on", "tunneling": "on", "graphical_session_recording": "on" },
                    "connection" : {
                        "protocol": "rdp",
                        "port": "3389",
                        "security": "any",
                        "ignore_server_cert": true,
                        "_comment_administrative_credentials": "Format: pamDirectory#title.pamDirectory#administrative_credentials - exact match needed",
                        "administrative_credentials": "XXX:Project1 AD.DomainAdmin"
                    }
                },
                "users": [{
                    "type": "pamUser",
                    "_comment_title": "username value from CSV or server-username if --prefix-names option is used",
                    "title": "xxx:admin",
                    "_comment_login": "username value from CSV",
                    "login": "xxx:Administrator",
                    "_comment_password": "password value from CSV",
                    "password": "xxx:P4ssw0rd_123",
                    "rotation_settings": { "rotation": "general", "enabled": "on", "schedule": {"type": "on-demand"} }
                }]
            }
        ]
    }
}"""


def _build_cli() -> argparse.ArgumentParser:
    p = argparse.ArgumentParser(
        description="Generate Keeper PAM import JSON file",
        formatter_class=argparse.RawTextHelpFormatter,
    )

    p.add_argument("-i", "--input-file", default="servers_to_import.csv",
                   help="Specify the input file - "
                   "CSV with hostname,user,password (default: %(default)s)")
    p.add_argument("-o", "--output-file", default="pam_import.json",
                   help="Specify the JSON output file (default: %(default)s)")
    p.add_argument("-t", "--template-file", default="import_template.json",
                   help="Specify the JSON template file (default: %(default)s)")
    p.add_argument("-s", "--show-template", action="store_true",
                   help="Show sample JSON template (overrides all options)")
    p.add_argument("-p", "--prefix-names", action="store_true",
                   help="Enable username prefixes (server1-admin vs admin)")
    return p


def _load_template(path: str) -> Dict[str, Any]:
    full_path = os.path.abspath(os.path.expanduser(path))
    if not os.path.isfile(full_path):
        print(f"JSON template file not found: {path}")
        print("Use --show-template option to get a sample template")
        sys.exit(1)

    res = {}
    with open(full_path, encoding="utf-8") as fp:
        res = json.load(fp)
    return res


def _read_csv(path: str) -> List[Dict[str, str]]:
    full_path = os.path.abspath(os.path.expanduser(path))
    if not os.path.isfile(full_path):
        print(f"CSV file not found: {path}", )
        sys.exit(2)
    fieldnames = ["hostname", "username", "password"]
    out: List[Dict[str, str]] = []
    with open(full_path, encoding="utf-8") as fp:
        reader = csv.DictReader(fp, fieldnames=fieldnames)
        header_row = next(reader)  # skip header row if present
        if list(header_row.values()) != fieldnames:
            fp.seek(0)
            reader = csv.DictReader(fp, fieldnames=fieldnames)
        for line_no, row in enumerate(reader, 0):
            h, u, p = (row.get("hostname", "").strip(),
                       row.get("username", "").strip(),
                       row.get("password", "").strip())
            if not all((h, u, p)):
                print(f"Row {line_no} incomplete - skipped")
                continue
            out.append({"hostname": h, "username": u, "password": p})
    return out


def _gen_data(csv_data: List[Dict[str, str]],
              template: Dict[str, Any],
              prefix_names: bool) -> Dict[str, Any]:

    data = copy.deepcopy(template)

    # pop out pamMachine template
    rsrs = data.get("pam_data", {}).get("resources") or []
    idx = next((i for i, item in enumerate(rsrs) if str(item.get("type")) == "pamMachine"), None)
    tmpl = rsrs.pop(idx) if idx is not None else {}
    if not tmpl:
        print("Unable to find pamMachine template")
        sys.exit(5)

    seen: set[str] = set()
    for row in csv_data:
        mach = copy.deepcopy(tmpl)
        user = row["username"]
        password = row["password"]
        host = row["hostname"]

        if host in seen:
            print(f"Duplicate hostname {host} - skipped")
            continue
        seen.add(host)

        # pamMachine
        mach["title"] = host
        mach["host"] = host
        if "options" not in mach["pam_settings"]:
            mach["pam_settings"]["options"] = {
                "rotation": "on",
                "connections": "on",
                "tunneling": "on",
                "graphical_session_recording": "on"
            }

        # pamUser
        users = mach.get("users") or []
        for usr in users:
            if "type" not in usr:
                usr["type"] = "pamUser"
            usr["title"] = f"{host}-{user}" if prefix_names else host
            usr["login"] = user
            usr["password"] = password
            if "rotation_settings" not in usr:
                usr["rotation_settings"] = {
                    "rotation": "general",
                    "enabled": "on",
                    "schedule": {"type": "on-demand"}
                }
        mach["users"] = users
        rsrs.append(mach)

    data["pam_data"]["resources"] = rsrs
    return data


def _write(fpath: Path, content: str):
    with fpath.open("w", encoding="utf-8") as fp:
        fp.write(content)
    print(f"Wrote {fpath}")


def write_import_json(data: Dict[str, Any], path: str):
    """ Generate JSON and save to file"""
    content = json.dumps(data, indent=2)
    _write(Path(path), content)


def prepare_temlpate(template: Dict[str, Any]) -> None:
    """ Prepare JSON template - populate missing defaults """
    tdic = json.loads(DEFAULT_IMPORT_TEMPLATE)
    if "project" not in template:
        template["project"] = tdic["project"]
    if "shared_folder_users" not in template:
        template["shared_folder_users"] = tdic["shared_folder_users"]
    if "shared_folder_resources" not in template:
        template["shared_folder_resources"] = tdic["shared_folder_resources"]
    if "pam_configuration" not in template:
        template["pam_configuration"] = tdic["pam_configuration"]
    env = str(template["pam_configuration"].get("environment"))
    if env != "local":
        print(f"This script works only with pam_configuration.environment = local, currently it is set to '{env}'")
        sys.exit(4)
    if (str(template["pam_configuration"].get("connections")).lower() != "on" or
            str(template["pam_configuration"].get("rotation")).lower() != "on"):
        print("connections and rotation must be set to 'on' in pam_configuration section - adjusted")
        template["pam_configuration"]["connections"] = "on"
        template["pam_configuration"]["rotation"] = "on"
    if "pam_data" not in template or not template["pam_data"].get("resources"):
        print('"pam_data": { "resources": [] } - must be present and non-empty')
        sys.exit(4)
    res = template["pam_data"].get("resources") or []
    if len(res) != 2:
        print('pam_data.resources[] - must define exactly two "machines": pamDirectory and pamUser')
        sys.exit(4)
    for i in (0, 1):
        mach_type = res[i].get("type") or ""
        mach_usrs = res[i].get("users") or []
        if ((i == 0 and mach_type != "pamDirectory") or (i == 1 and mach_type != "pamMachine") or not mach_usrs):
            print('Expected first machine type=pamDirectory and second type=pamUser, and each to have at least one pamUser')
            sys.exit(4)
        if "pam_settings" not in res[i]:
            print("Missing pam_settings section in pamDirectory or pamMachine")
            sys.exit(4)
        if ("connection" not in res[i]["pam_settings"] or
                "administrative_credentials" not in res[i]["pam_settings"]["connection"]):
            print("Missing pam_settings.connection.administrative_credentials in pamDirectory or pamMachine")
            sys.exit(4)
    # ToDo: verify admin users setup and cross references
    contents = json.dumps(template, indent=2)
    pos = contents.find('"XXX:')
    if pos != -1:
        print(f"Template still missing required values: {contents[pos:pos+80]}")
        sys.exit(4)


def main():
    """ Main function """
    args = _build_cli().parse_args()

    # --show-template overides any other options
    if args.show_template:
        print(DEFAULT_IMPORT_TEMPLATE)
        sys.exit(0)

    rows = _read_csv(args.input_file)
    tmpl = _load_template(args.template_file)
    prepare_temlpate(tmpl)
    print(f"Processing {len(rows)} servers")

    data = _gen_data(rows, tmpl, args.prefix_names)
    write_import_json(data, args.output_file)
    print(f"Import with `pam project import -f={args.output_file}")


if __name__ == "__main__":
    main()
